@@ -34,6 +34,10 @@ export class Colors {
     public static VRAM = '#B9C7E3'
     public static GPU = '#FFBA7D'
 
+    public static CHIP_GREY = '#989898'
+
     // TODO:JJ look for hex colors using '#[0-9a-fA-F]{3,8}'
     // TODO:JJ look for rgb colors using 'rgb(' and 'rgba('
+
+    // yellow: #FEED85
 }
\ No newline at end of file
