@@ -24,10 +24,106 @@ import { DataConnectorMetadata } from "./components/deploy/dataConnectorBrowser/
 import { Machine, NoMachine } from "./models/machine/Machine";
 
 import { SnackbarKey } from "notistack";
-import { Accordion, AccordionDetails, AccordionSummary, MenuItem, Select } from '@mui/material';
+import { Accordion, AccordionDetails, AccordionSummary, alpha, Button, Dialog, MenuItem, Select } from '@mui/material';
 import { withStyles } from '@mui/styles';
 
+/**
+ * The method to change the extension to be a certain view
+ */
+type Link = () => (any | Promise<any>)
+
+/**
+ * The specifier for how we want to change the extension to look
+ */
+type Target = {
+    parent?: Target
+    link?: Link
+    [key: string]: Target | Link
+}
+
 export class Global {
+
+    // The members in Target can be for dependency (we must switch to the deploy tab before switching to export mode) or they
+    // can be for organization (the settings popup doesn't do anything to prep its children, but it makes it easier to read)
+    public static readonly Target = {
+        SettingsPopup: {
+            PreferencesTab: {},
+            LimitsTab: {},
+            ConnectorsTab: {},
+            StorageTab: {},
+            BillingTab: {},
+        },
+        DeployTab: {
+            PackagesAccordion: {},
+            FilesAccordion: {
+                UploadPopup: {},
+                ConnectorPopup: {},
+            },
+            NotificationsPopup: {},
+            LaunchAccordion: {
+                SessionMode: {},
+                JobMode: {},
+            },
+            BasicMode: {},
+            ExpertMode: {},
+        },
+        MonitorTab: {},
+        MachinesTab: {},
+    }
+
+    /**
+     * This will change the view of the extension to show the specified target
+     * @param target which target to open to
+     */
+    public static async followLink(target: Target) {
+        // If things start failing all of a sudden, the solution may be to have the links
+        // only return once the setState has returned (the optional callback)
+
+        // If we have a parent, fun their link method first
+        if (target.parent) await Global.followLink(target.parent);
+        // Force javascript to context switch away to allow the dom to update and
+        // child link methods to be initialized before we call them
+        await new Promise(resolve => resolve(0))
+        // Call link if it exists, and wait for it if it is asynchronous
+        if (target.link) Promise.resolve(target.link());
+    }
+
+    /**
+     * Initialize a target with a method to achieve that view
+     * @param target the target to setup
+     * @param link the method to be run to change the view to the target
+     */
+    public static setLink(target: Target, link: Link) {
+        target.link = link
+        for (const [key, value] of Object.entries(target)) {
+            if (key === 'parent' || key === 'link') continue;
+            // This code will run for all child targets under 'target'
+            (value as any).parent = target
+        }
+    }
+
+    /**
+     * Deletes the method to change to this view, presumably because the component unmounted
+     * @param target the target to delete
+     */
+    public static deleteLink(target: Target) {
+        delete target.link
+        // we don't delete out children's parent because their great grandparent may be the
+        // only one actually mounted, and we need to be able to find them
+    }
+
+    /**
+     * Helpful function for removing all links specified under a target
+     * @param target the target to delete under
+     */
+    public static deleteLinksUnder(target: Target) {
+        for (const [key, value] of Object.entries(target)) {
+            if (key === 'parent' || key === 'link') continue;
+            // This code will run for all child targets under 'target'
+            Global.deleteLink(value as any)
+        }
+    }
+
     public static bounceAnimation = 'all 333ms cubic-bezier(0.33, 1.33, 0.66, 1) 0s'
     public static easeAnimation = 'all 150ms ease 0s'
 
@@ -50,9 +146,11 @@ export class Global {
     public static set version(version: string) {
         Global._version = version
         if (Global.shouldLogOnEmit) console.log('SignalEmit (' + new Date().getSeconds() + ')');
-        Global._onVersionSet.emit(void 0);
+        Global._onVersionSet.emit(version);
     }
 
+    public static get isDevVersion(): boolean { return Global._version.toLocaleLowerCase().includes('dev') }
+
     public static userHome: string = undefined;
     public static jupyterHome: string = undefined;
 
@@ -69,6 +167,7 @@ export class Global {
 
     private static canvas: HTMLCanvasElement = document.createElement("canvas");
     public static getStringWidth(text: string, font: string): number {
+        if (text == "" || text == undefined) return 0;
         // re-use canvas object for better performance
         var context: CanvasRenderingContext2D = this.canvas.getContext("2d");
         context.font = font;
@@ -161,12 +260,18 @@ export class Global {
         if (user == null && this._user != null) {
             this._user.fileTracker.stopPolling();
             this._user.fileChecker.stop();
+            this._user.appTracker.stopPolling();
+            this._metadata = null;
             this.snackbarClose.emit(null);
             if (Global.shouldLogOnEmit) console.log('SignalEmit (' + new Date().getSeconds() + ')');
             Global._onNullUser.emit(null)
             Global.labShell.collapseLeft();
             Global.labShell.collapseRight();
         }
+
+        // Always create a new metadata tracker
+        this._metadata = new OptumiMetadataTracker(this._tracker)
+
         setTimeout(() => {
             Global._user = user;
             // Reset 401 counter
@@ -218,14 +323,7 @@ export class Global {
     public static launchModeAccordionExpanded: boolean = false
     public static expertModeSelected: boolean = false
 
-    // Some markers to remember if a user has dismissed a warning snackbar
-    // public static freeTrialEgressLimitDismissed: boolean = false
-    // public static freeTrialStorageLimitDismissed: boolean = false
-    // public static freeTrialCreditLimitDismissed: boolean = false
-    // 
-    // public static starterEgressLimitDismissed: boolean = false
-    // public static starterStorageLimitDismissed: boolean = false
-    // public static starterCreditLimitDismissed: boolean = false
+    public static dismissalTimeout: number = 1.44e+7
 
     // We will use these for the steps for fractions
     private static generateFractionSteps = () => {
@@ -314,6 +412,40 @@ export const StyledAccordionDetails = withStyles({
     },
 })(AccordionDetails)
 
+export const WhiteTextButton = withStyles({
+	root: {
+		color: '#ffffff',
+        '&:hover': {
+            backgroundColor: alpha('#ffffff', 0.25)
+        },
+    },
+               
+})(Button);
+
+export const SkinnyButton = withStyles({
+    root: {
+        height: '20px',
+        padding: '0px',
+        fontSize: '12px',
+        lineHeight: '12px',
+        minWidth: '0px',
+     },
+     label: {
+        height: '20px',
+    },
+})(Button);
+
+export const PermanentPopup = withStyles((theme: Theme) => ({
+    root: {
+        margin: '12px',
+        padding: '0px',
+    },
+    paper: {
+        backgroundColor: 'var(--jp-layout-color1)',
+        minWidth: '640px',
+    },
+}))(Dialog);
+
 interface BoxProps {
     children?: React.ReactNode
     className?: string
