@@ -27,7 +27,7 @@ import { Colors } from '../Colors';
 
 interface IProps {
 	sx?: SxProps<Theme>
-	openUserDialogTo?: (page: number) => Promise<void> // This is somewhat spaghetti code-y, maybe think about revising
+	balance: number
 }
 
 interface IState {
@@ -105,7 +105,7 @@ export class DeployPage extends React.Component<IProps, IState> {
 			<DIV sx={Object.assign({overflow: 'auto'}, this.props.sx)}>
 				{((Global.labShell.currentWidget instanceof NotebookPanel) && (Global.tracker.currentWidget != null) && (Global.tracker.currentWidget.context.isReady)) ? (
 					<>
-						{Global.metadata.getMetadata() == undefined ? (
+						{Global.metadata == undefined || Global.metadata.getMetadata() == undefined ? (
 							<DIV sx={Object.assign({display: 'flex', flexFlow: 'column', overflow: 'hidden'}, this.props.sx)}>
 								<DIV sx={{flexGrow: 1, overflowY: 'auto', padding: '6px'}}>
 									<DIV sx={{ textAlign: 'center', margin: '12px'}}>
@@ -116,7 +116,7 @@ export class DeployPage extends React.Component<IProps, IState> {
 						) : (
 							<>
 								<DIV sx={{padding: '6px 10px'}}>
-									<FilesPanel openUserDialogTo={this.props.openUserDialogTo} />
+									<FilesPanel />
 									<LaunchMode />
 
 									<ReactCardFlip
@@ -129,7 +129,7 @@ export class DeployPage extends React.Component<IProps, IState> {
 											{flipCardHeader}
 											{!this.state.isFlipped && (
 												<>
-													<PreviewLaunchButton key={'preview-launch'}/>
+													<PreviewLaunchButton key={'preview-launch'} balance={this.props.balance}/>
 													{/* <PackageNotification /> */}
 												</>
 											)}
@@ -145,7 +145,7 @@ export class DeployPage extends React.Component<IProps, IState> {
 											/>
 											{this.state.isFlipped && (
 												<>
-													<PreviewLaunchButton key={'preview-launch'}/>
+													<PreviewLaunchButton key={'preview-launch'} balance={this.props.balance}/>
 													{/* <PackageNotification /> */}
 												</>
 											)}
@@ -176,6 +176,14 @@ export class DeployPage extends React.Component<IProps, IState> {
 	// Will be called automatically when the component is mounted
 	public componentDidMount = () => {
 		this._isMounted = true;
+		Global.setLink(Global.Target.DeployTab.BasicMode, () => {
+			this.safeSetState({isFlipped: false})
+			Global.expertModeSelected = false
+		})
+		Global.setLink(Global.Target.DeployTab.ExpertMode, () => {
+			this.safeSetState({isFlipped: true})
+			Global.expertModeSelected = true
+		})
         Global.labShell.currentChanged.connect(this.handleLabShellChange);
 		Global.tracker.currentChanged.connect(this.handleTrackerChange);
         Global.tracker.selectionChanged.connect(this.handleTrackerChange);
@@ -193,6 +201,8 @@ export class DeployPage extends React.Component<IProps, IState> {
         Global.metadata.getMetadataChanged().disconnect(this.handleMetadataChange);
 		// Global.metadata.getPackageChanged().disconnect(this.handlePackageChange);
 		Global.onUserChange.disconnect(this.handleUserChange)
+		Global.deleteLink(Global.Target.DeployTab.BasicMode)
+		Global.deleteLink(Global.Target.DeployTab.ExpertMode)
 		this._isMounted = false;
 	}
 
