@@ -31,11 +31,10 @@ export class StatusWrapper extends React.Component<IProps, IState> {
 
     public render = (): JSX.Element => {
         if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
-        var color: string;
-        if (this.props.statusColor.startsWith('var')) {
-            color = getComputedStyle(document.documentElement).getPropertyValue(this.props.statusColor.replace('var(', '').replace(')', '')).trim();
-        } else {
-            color = this.props.statusColor;
+        var color: string = this.props.statusColor;
+        if (!color) color = 'var(--jp-layout-color2)';
+        if (color.startsWith('var')) {
+            color = getComputedStyle(document.documentElement).getPropertyValue(color.replace('var(', '').replace(')', '')).trim();
         }
 
         return (
