@@ -15,11 +15,9 @@ import { Close as CloseIcon, /*OpenInNew as OpenInNewIcon*/ } from '@mui/icons-m
 
 import { ServerConnection } from '@jupyterlab/services';
 
-import { AccountConnectorsSubMenu, AccountFilesSubMenu, AccountPreferencesSubMenu, AccountLimitsSubMenu, AccountBillingSubMenu } from './settings/SettingsMenu';
+import { AccountConnectorsSubMenu, AccountStorageSubMenu, AccountPreferencesSubMenu, AccountLimitsSubMenu, AccountBillingSubMenu } from './settings/SettingsMenu';
 import { ShadowedDivider } from '../core';
-import { User } from '../models/User';
 import WarningPopup from '../core/WarningPopup';
-import { App } from '../models/application/App';
 import { Colors } from '../Colors';
 
 const StyledDialog = withStyles({
@@ -35,7 +33,7 @@ const StyledDialog = withStyles({
 export const enum Page {
     PREFERENCES = 0,
     LIMITS = 1,
-    FILES = 2,
+    STORAGE = 2,
     CONNECTORS = 3,
     BILLING = 4,
 }
@@ -44,7 +42,6 @@ interface IProps {
     sx?: SxProps<Theme>
     onOpen?: () => void
 	onClose?: () => void
-    getOpenTo?: (openTo: (page: Page) => Promise<void>) => void // This is somewhat spaghetti code-y, maybe think about revising
     balance: number
     machineCost: number
     serviceFeeCost: number
@@ -55,7 +52,6 @@ interface IProps {
 interface IState {
     open: boolean,
     selectedPanel: number,
-    showLogoutWithSessionPopup: boolean,
     validPhoneNumber: boolean,
     showCloseWithInvalidNumberPopup: boolean,
 }
@@ -69,19 +65,10 @@ export class UserDialog extends React.Component<IProps, IState> {
 		this.state = {
             open: false,
             selectedPanel: Page.PREFERENCES,
-            showLogoutWithSessionPopup: false,
             validPhoneNumber: true,
             showCloseWithInvalidNumberPopup: false,
 		};
     }
-
-    private resolveOpenToPromise: undefined | ((value: void | PromiseLike<void>) => void) = undefined
-    public openTo = (page: Page) => {
-        this.safeSetState({open: true, selectedPanel: page})
-        return new Promise<void>(resolve => {
-            this.resolveOpenToPromise = resolve
-        })
-    }
     
     private handleClickOpen = () => {
         if (this.props.onOpen) this.props.onOpen()
@@ -91,29 +78,6 @@ export class UserDialog extends React.Component<IProps, IState> {
 	private handleClose = () => {
         this.safeSetState({ open: false, validPhoneNumber: true });
         if (this.props.onClose) this.props.onClose();
-        if (this.resolveOpenToPromise) {
-			this.resolveOpenToPromise()
-			this.resolveOpenToPromise = undefined
-		}
-	}
-
-    private handleStopClicked = (app: App) => {
-		const settings = ServerConnection.makeSettings();
-		const url = settings.baseUrl + "optumi/stop-notebook";
-		const init: RequestInit = {
-			method: 'POST',
-			body: JSON.stringify({
-				workload: app.uuid,
-				module: app.modules[0].uuid,
-			}),
-		};
-		ServerConnection.makeRequest(
-			url,
-			init,
-			settings
-		).then((response: Response) => {
-			Global.handleResponse(response);
-		});
 	}
 
     public render = (): JSX.Element => {
@@ -175,28 +139,6 @@ export class UserDialog extends React.Component<IProps, IState> {
                         </DIV>
                         <DIV sx={{flexGrow: 1}} />
                         <DIV>
-                            <WarningPopup
-                                open={this.state.showLogoutWithSessionPopup}
-                                headerText="Are you sure?"
-                                bodyText={`You have a session that is currently active. If you log out, your session will be closed.`}
-                                cancel={{
-                                    text: `Cancel`,
-                                    onCancel: (prevent: boolean) => {
-                                        this.safeSetState({ showLogoutWithSessionPopup: false })
-                                    },
-                                }}
-                                continue={{
-                                    text: `Close it`,
-                                    onContinue: (prevent: boolean) => {
-                                        this.safeSetState({ showLogoutWithSessionPopup: false })
-                                        for (let app of Global.user.appTracker.activeSessions) {
-                                            this.handleStopClicked(app);
-                                        }
-                                        this.logout()
-                                    },
-                                    color: `error`,
-                                }}
-                            />
                             <Button 
                                 onClick={() => window.open('https://login.optumi.com/enduser/settings?iframe=true&iframeControlHideAll=true', '_blank')}
                                 disableElevation
@@ -212,14 +154,7 @@ export class UserDialog extends React.Component<IProps, IState> {
                                 sx={{ height: '36px', margin: '6px' }}
                                 variant="outlined"
                                 color="primary"
-                                onClick={() => {
-                                    const user: User = Global.user;
-                                    if (user.appTracker.activeSessions.length != 0) {
-                                        this.safeSetState({ showLogoutWithSessionPopup: true });
-                                    } else {
-                                        this.logout()
-                                    }
-                                }}
+                                onClick={this.logout}
                             >
                                 Logout
                             </Button>
@@ -296,7 +231,7 @@ export class UserDialog extends React.Component<IProps, IState> {
                                     >
                                         <Tab
                                             disableRipple
-                                            label='PREFERENCES'
+                                            label='Preferences'
                                             sx={{
                                                 padding: '0px',
                                                 minWidth: 'auto',
@@ -306,7 +241,7 @@ export class UserDialog extends React.Component<IProps, IState> {
                                         />
                                         <Tab
                                             disableRipple
-                                            label='LIMITS'
+                                            label='Limits'
                                             sx={{
                                                 padding: '0px',
                                                 minWidth: 'auto',
@@ -316,7 +251,7 @@ export class UserDialog extends React.Component<IProps, IState> {
                                         />
                                         <Tab
                                             disableRipple
-                                            label='CONNECTORS'
+                                            label='Connectors'
                                             sx={{
                                                 padding: '0px',
                                                 minWidth: 'auto',
@@ -326,17 +261,17 @@ export class UserDialog extends React.Component<IProps, IState> {
                                         />
                                         <Tab
                                             disableRipple
-                                            label='FILES'
+                                            label='Storage'
                                             sx={{
                                                 padding: '0px',
                                                 minWidth: 'auto',
                                                 minHeight: '36px',
                                             }}
-                                            value={Page.FILES}
+                                            value={Page.STORAGE}
                                         />
                                         <Tab
                                             disableRipple
-                                            label='BILLING'
+                                            label='Billing'
                                             sx={{
                                                 padding: '0px',
                                                 minWidth: 'auto',
@@ -412,7 +347,7 @@ export class UserDialog extends React.Component<IProps, IState> {
                                         <AccountLimitsSubMenu sx={{flexGrow: 1, overflowY: 'auto', maxWidth: '450px'}} />
                                     ) : this.state.selectedPanel == Page.BILLING ? (
                                         <AccountBillingSubMenu
-                                            sx={{flexGrow: 1, overflowY: 'auto', maxWidth: '450px'}}
+                                            sx={{flexGrow: 1, maxWidth: '450px'}}
                                             balance={this.props.balance}
                                             machineCost={this.props.machineCost}
                                             serviceFeeCost={this.props.serviceFeeCost}
@@ -421,15 +356,12 @@ export class UserDialog extends React.Component<IProps, IState> {
                                         />
                                     ) : this.state.selectedPanel == Page.CONNECTORS ? (
                                         <AccountConnectorsSubMenu sx={{flexGrow: 1, overflowY: 'auto'}} />
-                                    ) : this.state.selectedPanel == Page.FILES && (
-                                        <AccountFilesSubMenu sx={{flexGrow: 1, overflowY: 'auto'}} />
+                                    ) : this.state.selectedPanel == Page.STORAGE && (
+                                        <AccountStorageSubMenu sx={{flexGrow: 1, overflowY: 'auto'}} />
                                     )}
                                 </DIV>
                             </DialogContent>
                         </DIV>
-                    </DIV>
-                    <DIV sx={{display: 'inline-flex'}}>
-                        
                     </DIV>
 				</StyledDialog>
             </DIV>
@@ -453,11 +385,15 @@ export class UserDialog extends React.Component<IProps, IState> {
 
     public componentDidMount = () => {
         this._isMounted = true
-        if (this.props.getOpenTo) this.props.getOpenTo(this.openTo);
+        Global.setLink(Global.Target.SettingsPopup.PreferencesTab, async () => this.safeSetState({open: true, selectedPanel: Page.PREFERENCES}))
+        Global.setLink(Global.Target.SettingsPopup.LimitsTab, async () => this.safeSetState({open: true, selectedPanel: Page.LIMITS}))
+        Global.setLink(Global.Target.SettingsPopup.ConnectorsTab, async () => this.safeSetState({open: true, selectedPanel: Page.CONNECTORS}))
+        Global.setLink(Global.Target.SettingsPopup.StorageTab, async () => this.safeSetState({open: true, selectedPanel: Page.STORAGE}))
+        Global.setLink(Global.Target.SettingsPopup.BillingTab, async () => this.safeSetState({open: true, selectedPanel: Page.BILLING}))
     }
 
     public componentWillUnmount = () => {
-        if (this.props.getOpenTo) this.props.getOpenTo(() => new Promise<void>(() => {}));
+        Global.deleteLinksUnder(Global.Target.SettingsPopup)
         this._isMounted = false
     }
 
