@@ -6,7 +6,7 @@
 **/
 
 import * as React from 'react'
-import { DIV, Global } from '../../Global';
+import { DIV, Global, SkinnyButton } from '../../Global';
 
 import { SxProps, Theme } from '@mui/system';
 import { Button, Dialog, DialogTitle, Divider, IconButton } from '@mui/material';
@@ -15,7 +15,6 @@ import { Close, OpenInNew } from '@mui/icons-material';
 
 import { ShadowedDivider } from '../../core';
 import DataConnectorBrowser, { DataConnectorMetadata } from './dataConnectorBrowser/DataConnectorBrowser';
-import { Page } from '../UserDialog';
 
 const StyledDialog = withStyles({
     paper: {
@@ -27,21 +26,6 @@ const StyledDialog = withStyles({
     },
 })(Dialog);
 
-const StyledButton = withStyles({
-   root: {
-       height: '20px',
-       padding: '0px',
-       fontSize: '12px',
-       lineHeight: '12px',
-       minWidth: '0px',
-       margin: '0px 6px 6px 6px',
-       width: '100%',
-    },
-   label: {
-       height: '20px',
-   },
-})(Button);
-
 interface IProps {
     sx?: SxProps<Theme>
     onOpen?: () => void
@@ -93,14 +77,18 @@ export class AddDataConnectorsPopup extends React.Component<IProps, IState> {
         if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         return (
             <DIV sx={Object.assign({display: 'inline-flex', width: '50%'}, this.props.sx)} >
-                <StyledButton
+                <SkinnyButton
                     onClick={this.handleClickOpen}
                     variant='contained'
                     disableElevation
                     color='primary'
+                    sx={{
+                        margin: '0px 6px 6px 6px',
+                        width: '100%',
+                    }}
                 >
                     + Connector
-                </StyledButton>
+                </SkinnyButton>
                 <StyledDialog
 					open={this.state.open}
 					onClose={this.handleClose}
@@ -171,7 +159,7 @@ export class AddDataConnectorsPopup extends React.Component<IProps, IState> {
                             variant='contained'
                             color='primary'
                             onClick={() => {
-                                this.props.openUserDialogTo(Page.CONNECTORS)
+                                Global.followLink(Global.Target.SettingsPopup.ConnectorsTab)
                                 this.safeSetState({open: false})
                             }}
                             endIcon={<OpenInNew />}
@@ -186,11 +174,13 @@ export class AddDataConnectorsPopup extends React.Component<IProps, IState> {
 
     public componentDidMount = () => {
         this._isMounted = true
+        Global.setLink(Global.Target.DeployTab.FilesAccordion.ConnectorPopup, () => this.safeSetState({open: true}))
         document.addEventListener('keydown', this.handleKeyDown, false)
     }
 
     public componentWillUnmount = () => {
         document.removeEventListener('keydown', this.handleKeyDown, false)
+        Global.deleteLink(Global.Target.DeployTab.FilesAccordion.ConnectorPopup)
         this._isMounted = false
     }
 
