@@ -6,7 +6,9 @@
 **/
 
 import * as React from 'react'
-import { DIV, Global } from '../../Global';
+import { DIV, Global, SkinnyButton } from '../../Global';
+
+import { ServerConnection } from '@jupyterlab/services';
 
 import { SxProps, Theme } from '@mui/system';
 import { Button, Dialog, DialogTitle, IconButton } from '@mui/material';
@@ -26,21 +28,6 @@ const StyledDialog = withStyles({
     },
 })(Dialog);
 
-const StyledButton = withStyles({
-   root: {
-       height: '20px',
-       padding: '0px',
-       fontSize: '12px',
-       lineHeight: '12px',
-       minWidth: '0px',
-       margin: '0px 6px 6px 6px',
-       width: '100%',
-   },
-   label: {
-       height: '20px',
-   },
-})(Button);
-
 interface IProps {
     sx?: SxProps<Theme>
     onOpen?: () => void
@@ -76,9 +63,11 @@ export class AddFilesPopup extends React.Component<IProps, IState> {
     }
     
     private handleAdd = () => {
-        this.props.onFilesAdded(this.getSelectedFiles())
-        // console.log(this.getSelectedFiles())
-        this.handleClose()
+        const files = this.getSelectedFiles()
+        if (files.length > 0) {
+            this.props.onFilesAdded(files)
+            this.handleClose()
+        }
     }
 
     private handleKeyDown = (event: KeyboardEvent) => {
@@ -87,18 +76,31 @@ export class AddFilesPopup extends React.Component<IProps, IState> {
         if (event.key === 'Escape') this.handleClose();
     }
 
+    private request = async (path: string) => {
+        const settings = ServerConnection.makeSettings();
+		const url = settings.baseUrl + 'api/contents/' + path;
+		return ServerConnection.makeRequest(url, {}, settings).then(response => {
+			if (response.status !== 200) throw new ServerConnection.ResponseError(response);
+			return response.json();
+		})
+    }
+
     public render = (): JSX.Element => {
         if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         return (
             <DIV sx={Object.assign({display: 'inline-flex', width: '50%'}, this.props.sx)} >
-                <StyledButton
+                <SkinnyButton
                     onClick={this.handleClickOpen}
                     variant='contained'
                     disableElevation
                     color='primary'
+                    sx={{
+                        margin: '0px 6px 6px 6px',
+                        width: '100%',
+                    }}
                 >
                     + Upload
-                </StyledButton>
+                </SkinnyButton>
                 <StyledDialog
 					open={this.state.open}
 					onClose={this.handleClose}
@@ -153,7 +155,7 @@ export class AddFilesPopup extends React.Component<IProps, IState> {
                         </IconButton>
 					</DialogTitle>
                     <ShadowedDivider />
-                    <FileBrowser sx={{maxHeight: 'calc(100% - 60px - 2px)'}} onAdd={this.handleAdd} getSelectedFiles={(getSelectedFiles: () => FileMetadata[]) => this.getSelectedFiles = getSelectedFiles} />
+                    <FileBrowser sx={{maxHeight: 'calc(100% - 60px - 2px)'}} request={this.request} onAdd={this.handleAdd} getSelectedFiles={(getSelectedFiles: () => FileMetadata[]) => this.getSelectedFiles = getSelectedFiles} />
 				</StyledDialog>
             </DIV>
         );
@@ -161,11 +163,13 @@ export class AddFilesPopup extends React.Component<IProps, IState> {
 
     public componentDidMount = () => {
         this._isMounted = true
+        Global.setLink(Global.Target.DeployTab.FilesAccordion.UploadPopup, () => this.safeSetState({open: true}))
         document.addEventListener('keydown', this.handleKeyDown, false)
     }
 
     public componentWillUnmount = () => {
         document.removeEventListener('keydown', this.handleKeyDown, false)
+        Global.deleteLink(Global.Target.DeployTab.FilesAccordion.UploadPopup)
         this._isMounted = false
     }
 
