@@ -27,8 +27,6 @@ import { FileChecker } from '../../models/FileChecker';
 
 interface IProps {
     sx?: SxProps<Theme>
-
-    openUserDialogTo?: (page: number) => Promise<void> // This is somewhat spaghetti code-y, maybe think about revising
 }
 
 interface IState {
@@ -90,7 +88,7 @@ export class Files extends React.Component<IProps, IState> {
                             return `The following files exceed the maximum upload size (${FormatUtils.styleCapacityUnitValue()(Global.MAX_UPLOAD_SIZE)}):\n\n` + problems + `\n\nTo access larger data, use data connectors.`
                         })()}
                         continue={{
-                            text: `Ok`,
+                            text: `OK`,
                             onContinue: (prevent: boolean) => {
                                 this.safeSetState({ filesTooBig: [] })
                             },
@@ -151,7 +149,7 @@ export class Files extends React.Component<IProps, IState> {
                             this.safeSetState({ filesTooBig: filesTooBig })
                         }
                     }} />
-                    <AddDataConnectorsPopup openUserDialogTo={this.props.openUserDialogTo}
+                    <AddDataConnectorsPopup
                         onDataConnectorsAdded={async (metadatas: DataConnectorMetadata[]) => {
                             for (let dataConnectorModel of metadatas) {
                                 // Don't try to add the same file/directory more than once
