@@ -5,11 +5,12 @@
 **  To receive a copy of the licensing terms please write to contact@optumi.com or visit us at http://www.optumi.com.
 **/
 
-import { CSSProperties } from '@material-ui/core/styles/withStyles';
 import * as React from 'react'
 import { Global } from '../../Global';
-import { TextBox } from '../../core';
 
+import { CSSProperties } from '@mui/styles';
+
+import { TextBox } from '../../core';
 import { DataService } from './dataConnectorBrowser/DataConnectorDirListingItemIcon';
 import { BaseConnectorPopup } from '../../core/BaseConnectorPopup';
 
