@@ -132,7 +132,7 @@ export class ResourceFile extends React.Component<RFProps, RFState> {
                     display: 'inline-flex',
                     transition: Global.easeAnimation,
                 }}>
-                    {(!this.props.missingLocally && (compression.length > 0 || (upload.length > 0 && upload[0].total < 0))) ? (
+                    {!this.props.missingLocally && (compression.length > 0 && compression[0].total >= 0) ? (
                         <ExtraInfo reminder={compression.length > 0 ? compression[0].total == -1 ? '' : 'Compressed ' + compression[0].progress + '/' + compression[0].total + ' files' : ''}>
                             <DIV sx={{height: '16px', width: '16px', background: 'var(--jp-layout-color1)'}}>
                                 <CircularProgress
@@ -143,7 +143,7 @@ export class ResourceFile extends React.Component<RFProps, RFState> {
                                 />
                             </DIV>
                         </ExtraInfo>
-                    ) : (!this.props.missingLocally && (upload.length > 0) ? (
+                    ) : (!this.props.missingLocally && (upload.length > 0 && upload[0].total >= 0) ? (
                         <ExtraInfo reminder={FormatUtils.styleCapacityUnitValue()(upload[0].progress) + '/' + FormatUtils.styleCapacityUnitValue()(upload[0].total)}>
                             <DIV sx={{height: '16px', width: '16px', background: 'var(--jp-layout-color1)'}}>
                                 <CircularProgress
