@@ -43,9 +43,7 @@ export default class DataConnectorBrowser extends React.Component<IProps, IState
 
     constructor(props: IProps) {
         super(props)
-        if (this.props.getSelected) {
-            this.props.getSelected(this.getSelected);
-        }
+        if (this.props.getSelected) this.props.getSelected(this.getSelected);
         this.state = {
             dataConnectors: Global.lastDataConnectors,
             filter: '',
