@@ -10,15 +10,16 @@ import { DIV, Global } from '../../../Global';
 
 import { SxProps, Theme } from '@mui/system';
 
-import { ServerConnection } from '@jupyterlab/services';
 import { PageConfig } from '@jupyterlab/coreutils';
 
+import { ISignal } from '@lumino/signaling';
+
 import BreadCrumbs from './BreadCrumbs';
 import DirListing from './DirListing';
 import FilterBox from './FilterBox';
 
 export interface FileMetadata {
-    content: Array<File> | null,
+    content: Array<FileMetadata> | null,
     created: string,
     format: string | null,
     last_modified: string,
@@ -33,8 +34,12 @@ export interface FileMetadata {
 
 interface IProps {
     sx?: SxProps<Theme>
-    getSelectedFiles: (getSelectedFiles: () => FileMetadata[]) => void
+    request: (path: string) => Promise<any>
+    getSelectedFiles?: (getSelectedFiles: () => FileMetadata[]) => void
     onAdd?: () => void
+    onDownload?: (file: FileMetadata) => void
+    onDelete?: (file: FileMetadata) => void
+    updateSignal?: ISignal<any, void>
 }
 
 interface IState {
@@ -53,7 +58,7 @@ export default class FileBrowser extends React.Component<IProps, IState> {
 
     constructor(props: IProps) {
         super(props)
-        this.props.getSelectedFiles(this.getSelectedFiles)
+        if (this.props.getSelectedFiles) this.props.getSelectedFiles(this.getSelectedFiles)
         this.state = {
             serverRoot: PageConfig.getOption('serverRoot'),
             root: undefined,
@@ -64,28 +69,20 @@ export default class FileBrowser extends React.Component<IProps, IState> {
     }
 
     private getSelectedFiles = (): FileMetadata[] => {
-        return this.getSelected();
-    }
-
-    public request = async (path: string) => {
-        const settings = ServerConnection.makeSettings();
-		const url = settings.baseUrl + 'api' + path;
-		return ServerConnection.makeRequest(url, {}, settings).then(response => {
-			if (response.status !== 200) throw new ServerConnection.ResponseError(response);
-			return response.json();
-		})
+        // We don't want to return the internal contents in case they are changed
+        return JSON.parse(JSON.stringify(this.getSelected())) as FileMetadata[];
     }
 
     private handleOpen = (file: FileMetadata) => {
         if (file.type === 'directory') {
-            this.request('/contents/' + file.path).then(json => {
+            this.props.request(file.path).then(json => {
                 const newPath = [...this.state.path]
                 const depth = file.path.replace(/[^/]/g, '').length
                 while (newPath.length > depth) newPath.pop();
                 if (file !== this.state.root) newPath.push(file)
                 this.safeSetState({
                     path: newPath,
-                    files: json.content,
+                    files: [...json.content],
                 })
             })
         } else {
@@ -103,20 +100,29 @@ export default class FileBrowser extends React.Component<IProps, IState> {
                     filter={this.state.filter}
                     files={this.state.files}
                     onOpen={this.handleOpen}
-                    getSelected={getSelected => this.getSelected = getSelected}
+                    getSelected={this.props.getSelectedFiles ? getSelected => this.getSelected = getSelected : undefined}
+                    onDownload={this.props.onDownload}
+                    onDelete={this.props.onDelete}
                 />
             </DIV>
         )
     }
 
+    private handleUpdate = () => {
+        this.props.request(this.state.path.length == 0 ? '' : this.state.path[this.state.path.length-1].path).then(json => {
+            this.safeSetState({files: json.content});
+        })
+    }
+
     public componentDidMount = () => {
         this._isMounted = true
-        this.request('/contents').then(json => {
+        this.props.request('').then(json => {
             this.safeSetState({root: json, files: json.content});
         })
         // Override the JupyterLab context menu open (disable it)
         this.oldOpen = Global.lab.contextMenu.open;
         Global.lab.contextMenu.open = () => false;
+        if (this.props.updateSignal) this.props.updateSignal.connect(this.handleUpdate)
     }
 
     // Add context menu items back
@@ -124,6 +130,7 @@ export default class FileBrowser extends React.Component<IProps, IState> {
         // Restore the old JupyterLab context menu open
         Global.lab.contextMenu.open = this.oldOpen;
         this._isMounted = false
+        if (this.props.updateSignal) this.props.updateSignal.disconnect(this.handleUpdate)
     }
 
     private safeSetState = (map: any) => {
