@@ -6,16 +6,19 @@
 **/
 
 import * as React from 'react';
-import { Global } from '../../../Global';
+import { DIV, Global } from '../../../Global';
+
+import { SxProps, Theme } from '@mui/system';
 
 import { ComputeConfig } from '../../../models/ComputeConfig';
 import { User } from '../../../models/User';
 import { OptumiMetadataTracker } from '../../../models/OptumiMetadataTracker';
 import { Slider } from '../../../core';
 import FormatUtils from '../../../utils/FormatUtils';
+import { Colors } from '../../../Colors';
 
 interface IProps {
-    style?: React.CSSProperties,
+    sx?: SxProps<Theme>,
 }
 
 interface IState {}
@@ -71,14 +74,14 @@ export class ComputeComponent extends React.Component<IProps, IState> {
         if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         var user: User = Global.user;
         return (
-            <div style={this.props.style}>
+            <DIV sx={this.props.sx}>
                 <Slider
                     getValue={this.getCoresValue}
                     saveValue={this.saveCoresValue}
                     minValue={-1}
                     maxValue={user.machines.computeCoresMax}
                     label={'Cores'}
-                    color={'#f48f8d'}
+                    color={Colors.CPU}
                     showUnit
                 />
                 <Slider
@@ -87,7 +90,7 @@ export class ComputeComponent extends React.Component<IProps, IState> {
                     minValue={-1}
                     maxValue={user.machines.computeScoreMax}
                     label={'Score'}
-                    color={'#f48f8d'}
+                    color={Colors.CPU}
                     showUnit
                 />
                 <Slider
@@ -97,13 +100,13 @@ export class ComputeComponent extends React.Component<IProps, IState> {
                     step={1000000}
                     maxValue={user.machines.computeFrequencyMax}
                     label={'Frequency'}
-                    color={'#f48f8d'}
+                    color={Colors.CPU}
                     showUnit
                     styledUnit={FormatUtils.styleFrequencyUnit()}
                     styledValue={FormatUtils.styleFrequencyValue()}
                     unstyledValue={FormatUtils.unstyleFrequencyValue()}
                 />
-            </div>
+            </DIV>
         )
     }
 
