@@ -6,38 +6,22 @@
 **/
 
 import * as React from 'react';
-import { Global } from '../../../Global';
+import { DIV, Global, StyledMenuItem, StyledSelect } from '../../../Global';
+
+import { SxProps, Theme } from '@mui/system';
+import { SelectChangeEvent } from '@mui/material';
 
-import { MenuItem, Select, withStyles } from '@material-ui/core';
 import { GraphicsConfig } from '../../../models/GraphicsConfig';
 import { OptumiMetadataTracker } from '../../../models/OptumiMetadataTracker';
 
 interface IProps {
-    style?: React.CSSProperties,
+    sx?: SxProps<Theme>,
 }
 
 interface IState {
     selectedCard: string
 }
 
-const StyledSelect = withStyles({
-    root: {
-        fontSize: "var(--jp-ui-font-size1)",
-        width: '68px',
-    },
-    iconOutlined: {
-        right: '0px'
-    }
-}) (Select)
-
-const StyledMenuItem = withStyles({
-    root: {
-        fontSize: 'var(--jp-ui-font-size1)',
-        padding: '3px 3px 3px 6px',
-        justifyContent: 'center',
-    }
-}) (MenuItem)
-
 export class GraphicsEquipment extends React.Component<IProps, IState> {
     private _isMounted = false
 
@@ -68,7 +52,7 @@ export class GraphicsEquipment extends React.Component<IProps, IState> {
     
 
 
-    private handleCardChange = (event: React.ChangeEvent<{ value: unknown }>) => {
+    private handleCardChange = (event: SelectChangeEvent<unknown>, child: React.ReactNode) => {
         const value: string = event.target.value as string;
         this.safeSetState({ selectedCard: value });
         this.saveCardValue(value);
@@ -88,16 +72,16 @@ export class GraphicsEquipment extends React.Component<IProps, IState> {
     public render = (): JSX.Element => {
         if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         return (
-            <div style={{display: 'inline-flex', width: '100%', padding: '3px 0px'}}>
-                {/* <div 
-                    style={{
+            <DIV sx={{display: 'inline-flex', width: '100%', padding: '3px 0px'}}>
+                {/* <DIV 
+                    sx={{
                     minWidth: '68px',
                     lineHeight: '24px',
                     textAlign: 'center',
                     margin: '0px 6px',
                 }}/> */}
-                <div style={{display: 'inline-flex', width: '100%', justifyContent: 'center'}}>
-                    <div style={{padding: '0px 6px 0px 6px'}}>
+                <DIV sx={{display: 'inline-flex', width: '100%', justifyContent: 'center'}}>
+                    <DIV sx={{padding: '0px 6px 0px 6px'}}>
                         <StyledSelect
                             value={this.state.selectedCard}
                             variant='outlined'
@@ -107,19 +91,19 @@ export class GraphicsEquipment extends React.Component<IProps, IState> {
                         >
                             {this.getCardItems()}
                         </StyledSelect>
-                    </div>
-                </div>               
-                <div 
+                    </DIV>
+                </DIV>               
+                <DIV 
                     // title={this.props.tooltip || ''}
-                    style={{
+                    sx={{
                     minWidth: '68px',
                     lineHeight: '24px',
                     textAlign: 'center',
                     margin: '0px 6px',
                 }}>
                     {'Cards'}
-                </div>
-            </div>
+                </DIV>
+            </DIV>
         )
     }
 
