@@ -64,7 +64,7 @@ export class LaunchMode extends React.Component<IProps, IState> {
                                             {`The selected launch mode determines how your notebook will be run in the cloud.`}
                                         </P>
                                         <P sx={{whiteSpace: 'pre-line', fontWeight: 'bold', marginBottom: '0'}}>
-                                            {`session`}
+                                            {`Session`}
                                         </P>
                                         <P sx={{whiteSpace: 'pre-line'}}>
                                             {`If selected, Optumi will start a JupyterLab server in the cloud that you will connect to with your browser. A new browser tab will open automatically when the session is ready for use. You will be able to work interactively the same way you do on your local laptop, however notebook execution will take place on the remote server.
@@ -72,10 +72,10 @@ export class LaunchMode extends React.Component<IProps, IState> {
                                             This is often useful when developing or debugging your notebook.`}
                                         </P>
                                         <P sx={{whiteSpace: 'pre-line', fontWeight: 'bold', marginBottom: '0'}}>
-                                            {`job`}
+                                            {`Job`}
                                         </P>
                                         <P sx={{whiteSpace: 'pre-line'}}>
-                                            {`If selected, Optumi will take a snapshot of your current notebook and execute it in the cloud from start to finish. You will be able to see the notebook output as your job progresses, however you won’t be able to re-run individual cells within the notebook.
+                                            {`If selected, Optumi will take a snapshot of your current notebook and execute it in the cloud from start to finish. You will be able to see the notebook output as your job progresses, however you won't be able to re-run individual cells within the notebook.
 
                                             This is often useful when training or tuning hyperparameters. You can think of it as a fire-and-forget mode where you are free to close your browser without disrupting notebook execution.`}
                                         </P>
@@ -138,12 +138,20 @@ export class LaunchMode extends React.Component<IProps, IState> {
     // Will be called automatically when the component is mounted
 	public componentDidMount = () => {
         this._isMounted = true;
+        Global.setLink(Global.Target.DeployTab.LaunchAccordion, () => {
+            Global.launchModeAccordionExpanded = true
+            if (this._isMounted) this.forceUpdate();
+        })
+        Global.setLink(Global.Target.DeployTab.LaunchAccordion.SessionMode, () => this.saveValue('Session'))
+        Global.setLink(Global.Target.DeployTab.LaunchAccordion.JobMode, () => this.saveValue('Job'))
         Global.metadata.getMetadataChanged().connect(this.handleMetadataChange);
 	}
 
 	// Will be called automatically when the component is unmounted
 	public componentWillUnmount = () => {
         Global.metadata.getMetadataChanged().disconnect(this.handleMetadataChange);
+        Global.deleteLink(Global.Target.DeployTab.LaunchAccordion)
+        Global.deleteLinksUnder(Global.Target.DeployTab.LaunchAccordion)
         this._isMounted = false;
 	}
 
