@@ -6,16 +6,19 @@
 **/
 
 import * as React from 'react';
-import { Global } from '../../../Global';
+import { DIV, Global } from '../../../Global';
+
+import { SxProps, Theme } from '@mui/system';
 
 import { Slider } from '../../../core';
 import { MemoryConfig } from '../../../models/MemoryConfig';
 import { User } from '../../../models/User';
 import { OptumiMetadataTracker } from '../../../models/OptumiMetadataTracker';
 import FormatUtils from '../../../utils/FormatUtils';
+import { Colors } from '../../../Colors';
 
 interface IProps {
-    style?: React.CSSProperties,
+    sx?: SxProps<Theme>,
 }
 
 interface IState {}
@@ -41,7 +44,7 @@ export class MemoryComponent extends React.Component<IProps, IState> {
         if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         var user: User = Global.user;
         return (
-            <div style={this.props.style}>
+            <DIV sx={this.props.sx}>
                 <Slider
                     getValue={this.getSizeValue}
                     saveValue={this.saveSizeValue}
@@ -49,13 +52,13 @@ export class MemoryComponent extends React.Component<IProps, IState> {
                     step={1048576}
                     maxValue={user.machines.memorySizeMax}
                     label={'Size'}
-                    color={'#89858b'}
+                    color={Colors.RAM}
                     showUnit
                     styledUnit={FormatUtils.styleCapacityUnit()}
                     styledValue={FormatUtils.styleCapacityValue()}
                     unstyledValue={FormatUtils.unstyleCapacityValue()}
                 />
-            </div>
+            </DIV>
         )
     }
 
