@@ -6,15 +6,13 @@
 **/
 
 import * as React from 'react';
-import { Global } from '../../../Global';
+import { DIV, Global } from '../../../Global';
 
-import {
-    Divider,
-} from '@material-ui/core';
+import { SxProps, Theme } from '@mui/system';
+import { Divider } from '@mui/material';
 
 import { ResourceSelector } from './ResourceSelector';
 import { OptumiMetadataTracker } from '../../../models/OptumiMetadataTracker';
-
 import { GraphicsBasic } from './GraphicsBasic';
 import { GraphicsRating } from './GraphicsRating';
 import { GraphicsEquipment } from './GraphicsEquipment';
@@ -34,10 +32,10 @@ import { Expertise } from '../../../models/OptumiConfig';
 import { ComputeConfig } from '../../../models/ComputeConfig';
 import { GraphicsConfig } from '../../../models/GraphicsConfig';
 import { MemoryConfig } from '../../../models/MemoryConfig';
-import { Basic } from './Basic';
+import { Simplified } from './Simplified';
 
 interface IProps {
-    style?: React.CSSProperties,
+    sx?: SxProps<Theme>,
 }
 
 interface IState {}
@@ -101,7 +99,7 @@ export class ResourcesPanel extends React.Component<IProps, IState> {
         // For non-experimental users, we only need to look at one resource to decide what mode they are in
         // const basic: boolean = Global.metadata.getMetadata().metadata.graphics.expertise == Expertise.BASIC;
         return (
-            <div style={this.props.style}>
+            <DIV sx={this.props.sx}>
                 {Global.user.userExpertise >= 2 ? (
                     <>
                         <ResourceSelector title='GPU' getValue={this.getGraphicsLevel} saveValue={this.saveGraphicsLevel} childrenLabels={[Expertise.BASIC, Expertise.RATING, Expertise.EQUIPMENT, Expertise.COMPONENT]}>
@@ -132,11 +130,11 @@ export class ResourcesPanel extends React.Component<IProps, IState> {
                     </>
                 ) : (
                     <>
-                        <Basic />
+                        <Simplified />
                     </>
                 )}
                 
-            </div>
+            </DIV>
         );
     }
 
