@@ -6,15 +6,18 @@
 **/
 
 import * as React from 'react';
-import { Global } from '../../../Global';
+import { DIV, Global } from '../../../Global';
+
+import { SxProps, Theme } from '@mui/system';
 
 import { Slider } from '../../../core';
 import { OptumiMetadataTracker } from '../../../models/OptumiMetadataTracker';
 import { StorageConfig } from '../../../models/StorageConfig';
 import FormatUtils from '../../../utils/FormatUtils';
+import { Colors } from '../../../Colors';
 
 interface IProps {
-    style?: React.CSSProperties,
+    sx?: SxProps<Theme>,
 }
 
 interface IState {}
@@ -39,19 +42,19 @@ export class StorageRating extends React.Component<IProps, IState> {
     public render = (): JSX.Element => {
         if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         return (
-            <div style={this.props.style}>
+            <DIV sx={this.props.sx}>
                 <Slider
                     getValue={this.getValue}
                     saveValue={this.saveValue}
                     marks={Global.fractionMarks}
                     step={null}
                     label={'DSK'}
-                    color={'#7cdf8e'}
+                    color={Colors.DISK}
                     styledUnit={FormatUtils.styleRatingUnit()}
                     styledValue={FormatUtils.styleRatingValue()}
                     unstyledValue={FormatUtils.unstyleRatingValue()}
                 />
-            </div>
+            </DIV>
         )
     }
 
