@@ -32,7 +32,7 @@ export class ScrollableDiv extends React.Component<IProps, IState> {
     private getFormattedContents = (): JSX.Element => {
         var source: Update[] = this.props.source;
 		if (source.length == 0) {
-			return (<SPAN sx={{padding: '20px', display: 'inline-block', color: 'var(--jp-ui-font-color1)'}}>No output to display.</SPAN>);
+			return (<SPAN sx={{display: 'inline-block', color: 'var(--jp-ui-font-color1)'}}>No output to display</SPAN>);
 		} else {
             const lines: string[] = [];
             for (let outputLine of source) {
@@ -40,7 +40,7 @@ export class ScrollableDiv extends React.Component<IProps, IState> {
             }
             var ansiText = NotebookUtils.fixOverwrittenChars(lines);
             return (
-                <AnsiLink sx={{padding: '20px', display: 'inline-block', color: 'var(--jp-ui-font-color1)'}} key={lines[0]} text={ansiText} />
+                <AnsiLink sx={{display: 'inline-block', color: 'var(--jp-ui-font-color1)'}} key={lines[0]} text={ansiText} />
             );
         }
         return (<></>);
@@ -51,7 +51,7 @@ export class ScrollableDiv extends React.Component<IProps, IState> {
         if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
 
         return (
-            <DIV sx={{overflow: 'auto', width: '100%', height: '100%', whiteSpace: 'pre'}} innerRef={this.element}>
+            <DIV sx={{padding: '20px', overflow: 'auto', whiteSpace: 'pre'}} innerRef={this.element}>
                 {this.getFormattedContents()}
             </DIV>
         );
