@@ -9,14 +9,12 @@ import * as React from 'react';
 import { DIV, Global } from '../../Global';
 
 import { SxProps, Theme } from '@mui/system';
-import { Button, Divider, IconButton } from '@mui/material';
-import { GetApp as GetAppIcon, Delete as DeleteIcon } from '@mui/icons-material';
+import { Button, Divider, IconButton, } from '@mui/material';
+import { GetApp, Refresh } from '@mui/icons-material';
 
 import { ServerConnection } from '@jupyterlab/services';
 
-// import { ChangePasswordPopup } from './ChangePasswordPopup';
-import { CreditBucketCheckoutForm } from './CreditBucketCheckoutForm';
-import { Header, Switch, TextBox, TextBoxDropdown } from '../../core';
+import { Header, Switch, TextBox } from '../../core';
 import FormatUtils from '../../utils/FormatUtils';
 import DataConnectorBrowser, { DataConnectorMetadata } from '../deploy/dataConnectorBrowser/DataConnectorBrowser';
 import { AmazonS3ConnectorPopup } from '../deploy/AmazonS3ConnectorPopup';
@@ -26,15 +24,14 @@ import { KaggleConnectorPopup } from '../deploy/KaggleConnectorPopup';
 import { WasabiConnectorPopup } from '../deploy/WasabiConnectorPopup';
 // import { PhoneTextBox } from '../../core/PhoneTextBox';
 import { AzureBlobStorageConnectorPopup } from '../deploy/AzureBlobStorageConnector';
-import { FileMetadata } from '../deploy/fileBrowser/FileBrowser';
-import { FileTree } from '../FileTree';
-import { BillingType } from '../../models/User';
-import { MeteredBilling } from './MeteredBilling';
-import FileServerUtils from '../../utils/FileServerUtils';
+import FileBrowser, { FileMetadata } from '../deploy/fileBrowser/FileBrowser';
+import { SubscriptionActive } from './SubscriptionActive';
 
-import moment from 'moment';
-import { PhoneNumberFormat, PhoneNumberUtil } from 'google-libphonenumber';
-import { FreeTrial } from './Freetrial';
+import { FreeTrial } from './FreeTrial';
+import { PhoneTextBox } from '../../core/PhoneTextBox';
+import { SubscriptionEnded } from './SubscriptionEnded';
+import { CustomerState } from '../../core/CustomerState';
+import { FreeTrialEnded } from './FreeTrialEnded';
 
 // Properties from parent
 interface IAccountPreferencesSubMenuProps {
@@ -59,15 +56,9 @@ export class AccountPreferencesSubMenu extends React.Component<IAccountPreferenc
             switchKey: 0
         }
     }
-
-    // private getPasswordValue(): string { return '******' }
-    // private savePasswordValue(password: string) {
-    //     Global.user.changePassword("", "", password);
-    // }
     
     public render = (): JSX.Element => {
 		if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
-        const phoneUtil = PhoneNumberUtil.getInstance();
         return (
             <>
                 <DIV sx={Object.assign({padding: '6px'}, this.props.sx)}>
@@ -76,18 +67,8 @@ export class AccountPreferencesSubMenu extends React.Component<IAccountPreferenc
                         label='Name'
                         editPressRequired
                     /> */}
-                    {/* <DIV sx={{display: 'inline-flex', width: '100%'}}>
-                        <TextBox<string>
-                            sx={{flexGrow: 1}}
-                            getValue={this.getPasswordValue}
-                            saveValue={this.savePasswordValue}
-                            label='Password'
-                            labelWidth={LABEL_WIDTH}
-                        />
-                        <ChangePasswordPopup sx={{margin: '8px 0px', height: '20px', fontSize: '12px', lineHeight: '12px'}}/>
-                    </DIV> */}
-                    {/* <PhoneTextBox
-                        getValue={() => Global.user.phoneNumber}
+                    <PhoneTextBox
+                        getValue={() => Global.user.phoneNumber ? Global.user.phoneNumber : ''}
                         saveValue={(phoneNumber: string) => {
                             if (phoneNumber == '') Global.user.notificationsEnabled = false;
                             Global.user.phoneNumber = phoneNumber;
@@ -97,13 +78,13 @@ export class AccountPreferencesSubMenu extends React.Component<IAccountPreferenc
                         validOnBlur={this.props.phoneValidOnBlur}
                         label='Phone'
                         labelWidth={LABEL_WIDTH}
-                    /> */}
+                    />
                     <Switch
                         key={this.state.switchKey}
                         getValue={() => Global.user.notificationsEnabled }
                         saveValue={(notificationsEnabled: boolean) => { Global.user.notificationsEnabled = notificationsEnabled }}
-                        label={'Enable SMS notifications to ' + phoneUtil.format(phoneUtil.parse(Global.user.phoneNumber, 'US'), PhoneNumberFormat.INTERNATIONAL)}
-                        // disabled={Global.user.phoneNumber == ''}
+                        label={'Enable SMS notifications to ' + Global.user.phoneNumber}
+                        disabled={Global.user.phoneNumber == ''}
                         labelBefore
                         flip
                     />
@@ -125,7 +106,7 @@ export class AccountPreferencesSubMenu extends React.Component<IAccountPreferenc
                         <Button 
                             variant="outlined"
                             color="primary"
-                            startIcon={<GetAppIcon />}
+                            startIcon={<GetApp />}
                             sx={{width: '100%'}}
                             onClick={async () => {
                                 const data = [];
@@ -251,8 +232,8 @@ export class AccountLimitsSubMenu extends React.Component<IAccountLimitsSubMenuP
     private getMaxMachinesValue(): number { return Global.user.maxMachines }
     private saveMaxMachinesValue(value: number) { Global.user.maxMachines = value }
 
-    private getUserHoldoverTimeValue(): number { return Global.user.userHoldoverTime }
-    private saveUserHoldoverTimeValue(userHoldoverTime: number) { Global.user.userHoldoverTime = userHoldoverTime }
+    private getUserHoldoverTimeValue(): number { return Math.round(Global.user.userHoldoverTime / 60) }
+    private saveUserHoldoverTimeValue(userHoldoverTime: number) { Global.user.userHoldoverTime = userHoldoverTime * 60 }
 
     public render = (): JSX.Element => {
 		if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
@@ -290,22 +271,35 @@ export class AccountLimitsSubMenu extends React.Component<IAccountLimitsSubMenuP
                     helperText='Max number of concurrent machines'
                     disabledMessage={emUpSub}
                 />
-                <TextBoxDropdown
+                <TextBox<number>
+                    getValue={this.getUserHoldoverTimeValue}
+                    saveValue={this.saveUserHoldoverTimeValue}
+                    styledUnitValue={(value: number) => { return isNaN(value) ? "" : value.toFixed() }}
+                    unstyleUnitValue={(value: string) => { return value.replace(/\d/g, '').length > 0 ? Number.NaN : Number.parseFloat(value); }}
+                    label='Auto-release'
+                    labelWidth={LABEL_WIDTH}
+                    onFocus={() => this.safeSetState({holdoverFocused: true})}
+                    onBlur={() => this.safeSetState({holdoverFocused: false})}
+                    helperText={this.state.holdoverFocused ? `Must be between 0 and ${Global.user.maxHoldoverTime / 60} minutes` : 'Time in minutes before releasing idle machines'}
+                    minValue={0}
+                    maxValue={+(Global.user.maxHoldoverTime / 60).toFixed()}
+                />
+                {/* <TextBoxDropdown
                     getValue={this.getUserHoldoverTimeValue}
                     saveValue={this.saveUserHoldoverTimeValue}
                     unitValues={[
-                        {unit: 'seconds', value: 1},
+                        // {unit: 'seconds', value: 1},
                         {unit: 'minutes', value: 60},
-                        {unit: 'hours', value: 3600},
+                        // {unit: 'hours', value: 3600},
                     ]}
                     label='Auto-release'
                     labelWidth={LABEL_WIDTH}
                     onFocus={() => this.safeSetState({holdoverFocused: true})}
                     onBlur={() => this.safeSetState({holdoverFocused: false})}
-                    helperText={this.state.holdoverFocused ? `Must be between 0 seconds and ${Global.user.maxHoldoverTime / 3600} hours` : 'Time before releasing idle machines'}
+                    helperText={this.state.holdoverFocused ? `Must be between 0 and ${Global.user.maxHoldoverTime / 60} minutes` : 'Time in minutes before releasing idle machines'}
                     minValue={0}
                     maxValue={Global.user.maxHoldoverTime}
-                />
+                /> */}
             </DIV>
         </>;
     }
@@ -383,39 +377,19 @@ export class AccountBillingSubMenu extends React.Component<IAccountBillingSubMen
         return (
             <>
                 <DIV sx={Object.assign({padding: '6px'}, this.props.sx)}>
-                    {Global.user.billingType == BillingType.CREDIT_BUCKET ? (
-                        <>
-                            <DIV sx={{display: 'inline-flex', width: '100%', padding: '3px 0px'}}>
-                                <DIV 
-                                    sx={{
-                                    lineHeight: '24px',
-                                    margin: '0px 12px',
-                                    flexGrow: 1,
-                                }}
-                                >
-                                    {'Remaining balance'}
-                                </DIV>
-                                <DIV sx={{padding: '0px 6px 0px 6px'}}>
-                                    {'$' + (-this.state.balance).toFixed(2)}
-                                </DIV>
-                            </DIV>
-                            <DIV sx={{width: '250px'}}>
-                                <CreditBucketCheckoutForm />
-                            </DIV>
-                        </>
+                    {Global.user.isSubscribed() ? (
+                        <SubscriptionActive 
+                            machineCost={this.props.machineCost}
+                            serviceFeeCost={this.props.serviceFeeCost}
+                            storageCost={this.props.storageCost}
+                            egressCost={this.props.egressCost}
+                        />
+                    ) : Global.user.customerState == CustomerState.FREE_TRIAL ? (
+                        <FreeTrial balance={this.props.balance}/>
+                    ) : Global.user.customerState == CustomerState.FREE_TRIAL_ENDED ? (
+                        <FreeTrialEnded balance={this.props.balance}/>
                     ) : (
-                        <>
-                            {Global.user.subscriptionActive ? (
-                                <MeteredBilling 
-                                    machineCost={this.props.machineCost}
-                                    serviceFeeCost={this.props.serviceFeeCost}
-                                    storageCost={this.props.storageCost}
-                                    egressCost={this.props.egressCost}
-                                />
-                            ) : (
-                                <FreeTrial balance={this.props.balance}/>
-                            )}
-                        </>
+                        <SubscriptionEnded balance={this.props.balance}/>
                     )}
                 </DIV>
             </>
@@ -453,15 +427,23 @@ export class AccountBillingSubMenu extends React.Component<IAccountBillingSubMen
         });
     }
     
+    private handleUserChange = () => {
+        this.forceUpdate();
+    }
+
     // Will be called automatically when the component is mounted
 	public componentDidMount = () => {
         this._isMounted = true;
         this.polling = true;
         this.receiveUpdate();
+        Global.onUserChange.connect(this.handleUserChange);
+        Global.user.userInformationChanged.connect(this.handleUserChange);
 	}
 
 	// Will be called automatically when the component is unmounted
 	public componentWillUnmount = () => {
+        Global.user.userInformationChanged.disconnect(this.handleUserChange);
+        Global.onUserChange.disconnect(this.handleUserChange);
         this._isMounted = false;
         this.polling = false;
         if (this.timeout != null) clearTimeout(this.timeout)
@@ -570,7 +552,7 @@ export class AccountConnectorsSubMenu extends React.Component<IAccountConnectors
                                 newDataConnectors = newDataConnectors.filter(dataConnector => dataConnector.name !== dataConnectorMetadata.name)
                                 this.safeSetState({dataConnectors: newDataConnectors})
                                 this.forceNewBrowser()
-                            }).then(() => Global.dataConnectorChange.emit(void 0));                   
+                            }).then(() => Global.dataConnectorChange.emit());                   
                         }}
                     />
                     <Divider sx={{marginTop: '33px'}}/>
@@ -634,14 +616,15 @@ export class AccountConnectorsSubMenu extends React.Component<IAccountConnectors
 }
 
 // Properties from parent
-interface IAccountFilesSubMenuProps {
+interface IAccountStorageSubMenuProps {
 	sx?: SxProps<Theme>
 }
 
-interface IAccountFilesSubMenuState {}
+interface IAccountStorageSubMenuState {}
 
-export class AccountFilesSubMenu extends React.Component<IAccountFilesSubMenuProps, IAccountFilesSubMenuState> {
-    constructor(props: IAccountFilesSubMenuProps) {
+export class AccountStorageSubMenu extends React.Component<IAccountStorageSubMenuProps, IAccountStorageSubMenuState> {
+    
+    constructor(props: IAccountStorageSubMenuProps) {
         super(props);
         this.state = {
             files: [],
@@ -652,117 +635,76 @@ export class AccountFilesSubMenu extends React.Component<IAccountFilesSubMenuPro
 
     public render = (): JSX.Element => {
 		if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
-        const files = Global.user.fileTracker.files;
-        var sorted: FileMetadata[] = !files ? [] : files.sort(FileServerUtils.sortFiles);
-        const total = Global.user.fileTracker.total
         return <>
-            <DIV sx={Object.assign({padding: '20px 6px 6px 20px'}, this.props.sx)}>
-                <DIV>
-                    Listed files are securely stored in the Optumi platform. If you want to delete a file click on the associated trash can.
-                    {total > 0 && <>
-                        <br />
-                        <br />
-                        Total used storage: {FormatUtils.styleCapacityUnitValue()(Global.user.fileTracker.total)}
-                    </>}
+            <DIV sx={Object.assign({display: 'flex', flexDirection: 'column', overflowY: 'visible'}, this.props.sx)}>
+                <DIV sx={{padding: '20px'}}>
+                    <DIV sx={{lineHeight: '36px'}}>
+                        Used storage: {FormatUtils.styleStorageOrEgress(Global.user.fileTracker.total, Global.user.fileTracker.limit)}
+                        <IconButton
+                            sx={{ width: '36px', height: '36px', padding: '3px' }}
+                            size='large'
+                            onClick={() => Global.user.fileTracker.receiveUpdate(false)}
+                        >
+                            <Refresh sx={{ width: '30px', height: '30px', padding: '3px' }} />
+                        </IconButton>
+                    </DIV>
                 </DIV>
-                <FileTree
-                    files={sorted}
-                    fileTitle={file => (
-`Name: ${file.name}
-${file.size === null ? '' : `Size: ${FormatUtils.styleCapacityUnitValue()(file.size)} (${file.size} bytes)
-`}${file.path === '' ? '' : `Path: ${file.path.replace(file.name, '').replace(/\/$/, '')}
-`}Modified: ${moment(file.last_modified).format('YYYY-MM-DD hh:mm:ss')}`
-                    )}
-                    fileHidableIcon={file => ({
-                        width: 72,
-                        height: 36,
-                        icon: (
-                            <>
-                                <IconButton
-                                    size='large'
-                                    onClick={() => this.downloadFile(file)}
-                                    sx={{ width: '36px', height: '36px', padding: '3px' }}
-                                >
-                                    <GetAppIcon sx={{ width: '30px', height: '30px', padding: '3px' }} />
-                                </IconButton>
-                                <IconButton
-                                    size='large'
-                                    onClick={() => this.deleteFile(file)}
-                                    sx={{ width: '36px', height: '36px', padding: '3px' }}
-                                >
-                                    <DeleteIcon sx={{ width: '30px', height: '30px', padding: '3px' }} />
-                                </IconButton>
-                            </>
-                        ),
-                    })}
-                    directoryHidableIcon={path => ({
-                        width: 72,
-                        height: 36,
-                        icon: (
-                            <>
-                                <IconButton
-                                    size='large'
-                                    onClick={() => this.downloadDirectory(path)}
-                                    sx={{ width: '36px', height: '36px', padding: '3px' }}
-                                >
-                                    <GetAppIcon sx={{ width: '30px', height: '30px', padding: '3px' }} />
-                                </IconButton>
-                                <IconButton
-                                    size='large'
-                                    onClick={() => this.deleteDirectory(path)}
-                                    sx={{ width: '36px', height: '36px', padding: '3px' }}
-                                >
-                                    <DeleteIcon sx={{ width: '30px', height: '30px', padding: '3px' }} />
-                                </IconButton>
-                            </>
-                        ),
-                    })}
-                />
+                <FileBrowser
+                    sx={{maxHeight: 'calc(100% - 77px)', flexGrow: 1}}
+                    request={(path: string) => Global.user.fileTracker.getContentsForFileBrowser(path)}
+                    updateSignal={Global.user.fileTracker.getFilesChanged()}
+                    onDownload={(file) => {
+                        if (file.type == 'directory') {
+                            const fixedPath = Global.convertJupyterPathToOptumiPath(file.path)
+                            this.downloadFiles(Global.user.fileTracker.expandDirectory(fixedPath, false), fixedPath)
+                        } else {
+                            this.downloadFiles([file])
+                        }
+                    }}
+                    onDelete={(file) => {
+                        if (file.type == 'directory') {
+                            const fixedPath = Global.convertJupyterPathToOptumiPath(file.path)
+                            this.deleteFiles(Global.user.fileTracker.expandDirectory(fixedPath), fixedPath)
+                        } else {
+                            this.deleteFiles(file.content)
+                        }
+                    }}
+                    />
             </DIV>
         </>;
     }
 
-    private async deleteFile(file: FileMetadata) {
-        Global.user.fileTracker.deleteFiles([file]);
+    private async deleteFiles(files: FileMetadata[], directory: string = "") {
+        Global.user.fileTracker.deleteFiles(files, directory);
     }
 
-    private async downloadFile(file: FileMetadata) {
-		Global.user.fileTracker.downloadFiles(file.path, [file], false);
+    private async downloadFiles(files: FileMetadata[], directory: string = "") {
+		Global.user.fileTracker.downloadFiles(files[0].path, files, false, directory);
     }
 
-    private async deleteDirectory(path: string) {
-        let filesToDelete: FileMetadata[] = []
-        for (let file of Global.user.fileTracker.files) {
-            if (file.path.startsWith('~/' + path)) {
-                filesToDelete.push(file)
-            }
-        }
-        Global.user.fileTracker.deleteFiles(filesToDelete);
+    private handleUserChange = () => {
+        Global.user.fileTracker.getFilesChanged().connect(this.handleFilesChange);
     }
 
-    private async downloadDirectory(path: string) {
-        let filesToDownload: FileMetadata[] = []
-        for (let file of Global.user.fileTracker.files) {
-            if (file.path.startsWith('~/' + path)) {
-                filesToDownload.push(file)
-            }
-        }
-        Global.user.fileTracker.downloadFiles(path, filesToDownload, false, [], path);
+    private handleFilesChange = () => {
+        this.forceUpdate();
     }
 
-    private handleFilesChange = () => this.forceUpdate();
-
     // Will be called automatically when the component is mounted
 	public componentDidMount = () => {
-        if (Global.user != null) Global.user.fileTracker.getFilesChanged().connect(this.handleFilesChange);
+        if (Global.user != null) {
+            this.handleUserChange();
+        }
+        Global.onUserChange.connect(this.handleUserChange);
 	}
 
 	// Will be called automatically when the component is unmounted
 	public componentWillUnmount = () => {
         if (Global.user != null) Global.user.fileTracker.getFilesChanged().disconnect(this.handleFilesChange);
+        Global.onUserChange.disconnect(this.handleUserChange);
     }
 
-    public shouldComponentUpdate = (nextProps: IAccountFilesSubMenuProps, nextState: IAccountFilesSubMenuState): boolean => {
+    public shouldComponentUpdate = (nextProps: IAccountStorageSubMenuProps, nextState: IAccountStorageSubMenuState): boolean => {
         try {
             if (JSON.stringify(this.props) != JSON.stringify(nextProps)) return true;
             if (JSON.stringify(this.state) != JSON.stringify(nextState)) return true;
@@ -773,7 +715,7 @@ ${file.size === null ? '' : `Size: ${FormatUtils.styleCapacityUnitValue()(file.s
         }
     }
 }
-export class TeamSubMenu extends React.Component<IAccountFilesSubMenuProps, IAccountFilesSubMenuState> {
+export class TeamSubMenu extends React.Component<IAccountStorageSubMenuProps, IAccountStorageSubMenuState> {
     public render = (): JSX.Element => {
 		if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         return (
