@@ -135,21 +135,29 @@ export class BaseConnectorPopup extends React.Component<IProps, IState> {
             settings
         ).then((response: Response) => {
             Global.handleResponse(response);
-        }).then(() => {
-            this.safeSetState({ waiting: false, addSpinning: false, createSpinning: false })
-            if (add && !this.nameHasError(this.state.name)) {
-                const tracker = Global.metadata
-                const optumi = tracker.getMetadata()
-                var dataConnectors = optumi.config.upload.dataConnectors
-                dataConnectors.push(new DataConnectorUploadConfig({
-                    name: this.state.name,
-                    dataService: this.props.dataService,
-                }))
-                tracker.setMetadata(optumi)
+            return response.json();
+        }).then((body: any) => {
+            if (body.message) {
+                // This means there was a failure
+                // Show what went wrong
+                this.safeSetState({ waiting: false, addSpinning: false, createSpinning: false, errorMessage: body.message });
+            } else {
+                this.safeSetState({ waiting: false, addSpinning: false, createSpinning: false })
+                if (add && !this.nameHasError(this.state.name)) {
+                    const tracker = Global.metadata
+                    const optumi = tracker.getMetadata()
+                    var dataConnectors = optumi.config.upload.dataConnectors
+                    dataConnectors.push(new DataConnectorUploadConfig({
+                        name: this.state.name,
+                        dataService: this.props.dataService,
+                    }))
+                    tracker.setMetadata(optumi)
+                }
+                // Success
+                this.handleClose()
             }
-            // Success
-            this.handleClose()
         }, (error: ServerConnection.ResponseError) => {
+            console.error(error)
             error.response.text().then((text: string) => {
                 // Show what went wrong
                 this.safeSetState({ waiting: false, addSpinning: false, createSpinning: false, errorMessage: text });
@@ -173,7 +181,6 @@ export class BaseConnectorPopup extends React.Component<IProps, IState> {
                     handleClick={this.handleClickOpen}
                 />
                 <StyledDialog
-                    onClose={(event: object, reason: string) => void 0}
                     open={this.state.open}
                     scroll='paper'
                 >
