@@ -95,16 +95,13 @@ export class IntentSlider extends React.Component<IProps, IState> {
                 color: this.props.color,
                 opacity: 0,
                 boxSizing: 'border-box',
-                // border: "1px solid " + darken(this.props.color, 0.25),
                 borderRadius: '8px',
             },
             rail: { // right side
                 height: '16px',
                 width: '100%',
-                opacity: 1,
-                color: 'var(--jp-layout-color2)',
+                opacity: 0,
                 boxSizing: 'border-box',
-                // border: '1px solid ' + (this.isLightMode ? darken('#eeeeee', 0.25) : lighten('#424242', 0.25)),
                 borderRadius: '8px',
             },
             mark: {
@@ -204,7 +201,7 @@ export class IntentSlider extends React.Component<IProps, IState> {
                             height: '0px', overflow: 'visible', pointerEvents: 'none' // Pass click events to the slider behind
                         }}
                     >
-                        {'Cheaper'}
+                        {'cheaper'}
                     </DIV>
                     <DIV sx={{
                             position: 'absolute',
@@ -219,7 +216,7 @@ export class IntentSlider extends React.Component<IProps, IState> {
                             height: '0px', overflow: 'visible', pointerEvents: 'none' // Pass click events to the slider behind    
                         }}
                     >
-                        {'Faster'}
+                        {'faster'}
                     </DIV>
                 </DIV>
             </DIV>
