@@ -1,10 +1,17 @@
+/*
+**  Copyright (C) Optumi Inc - All rights reserved.
+**
+**  You may only use this code under license with Optumi Inc and any distribution or modification is strictly prohibited.
+**  To receive a copy of the licensing terms please write to contact@optumi.com or visit us at http://www.optumi.com.
+**/
+
 import * as React from 'react'
 import { Global } from '../Global';
 
-import { Popover, Theme, withTheme } from '@material-ui/core';
+import { Theme } from '@mui/system';
+import { Popover } from '@mui/material';
 
 interface IProps {
-    theme: Theme
     button: JSX.Element
     popup: JSX.Element
     onOpen?: () => void
@@ -19,7 +26,7 @@ interface IState {
     anchorEl: any
 }
 
-class Popper extends React.Component<IProps, IState> {
+export class Popper extends React.Component<IProps, IState> {
     _isMounted = false;
     stopPropagation = false;
 
@@ -54,12 +61,11 @@ class Popper extends React.Component<IProps, IState> {
 
     public render = (): JSX.Element => {
         if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
-        const theme: Theme = this.props.theme
 		return (
             <>
                 {React.cloneElement(this.props.button, {onClick: this.handleClick})}
                 <Popover
-                    style={{top: theme.spacing(0.5)}}
+                    sx={{top: (theme: Theme) => theme.spacing(0.5)}}
                     open={this.state.open}
                     anchorEl={this.state.anchorEl}
                     onClose={this.handleClose}
@@ -77,7 +83,7 @@ class Popper extends React.Component<IProps, IState> {
                         }
                     }}
                 >
-                    {React.cloneElement(this.props.popup, {style: Object.assign({minWidth: 'var(--jp-sidebar-min-width)'}, this.props.popup.props.style)})}
+                    {React.cloneElement(this.props.popup, {sx: Object.assign({minWidth: 'var(--jp-sidebar-min-width)'}, this.props.popup.props.sx)})}
                 </Popover>
             </>
 		);
@@ -124,5 +130,3 @@ class Popper extends React.Component<IProps, IState> {
         }
     }
 }
-const ThemedPopper = withTheme(Popper)
-export {ThemedPopper as Popper}
\ No newline at end of file
