@@ -7,12 +7,15 @@
 
 import * as React from 'react'
 import { Global } from '../Global';
-import Plotly, { Datum, PlotData } from 'plotly.js'
+
 import { Update } from '../models/Update';
 import { App } from '../models/application/App';
-import Plot, { Figure } from 'react-plotly.js';
 import FormatUtils from '../utils/FormatUtils';
 
+import Plotly, { Datum, PlotData } from 'plotly.js'
+import Plot, { Figure } from 'react-plotly.js';
+import { Colors } from '../Colors';
+
 interface IProps {
     app: App
 }
@@ -255,33 +258,33 @@ export class ResourceGraph extends React.Component<IProps, IState> {
         let newState: Partial<IState> = {
             data: [
                 { x: [], y: [], mode: 'lines', type: 'scatter', line: { shape: 'spline', width: 0 }, name: 'NET max', hoverinfo: 'none', legendgroup: 'NET', showlegend: false },
-                { x: [], y: [], mode: 'lines', type: 'scatter', line: { shape: 'spline', color: '#10A0F9' }, fill: 'tonexty', fillcolor: '#10A0F960', name: 'NET', legendgroup: 'NET' },
-                { x: [], y: [], mode: 'lines', type: 'scatter', line: { shape: 'spline', width: 0 }, fill: 'tonexty', fillcolor: '#10A0F960', name: 'NET min', hoverinfo: 'none', legendgroup: 'NET', showlegend: false },
+                { x: [], y: [], mode: 'lines', type: 'scatter', line: { shape: 'spline', color: Colors.NETWORK }, fill: 'tonexty', fillcolor: Colors.NETWORK + '60', name: 'NET', legendgroup: 'NET' },
+                { x: [], y: [], mode: 'lines', type: 'scatter', line: { shape: 'spline', width: 0 }, fill: 'tonexty', fillcolor: Colors.NETWORK + '60', name: 'NET min', hoverinfo: 'none', legendgroup: 'NET', showlegend: false },
 
                 { x: [], y: [], mode: 'lines', type: 'scatter', line: { shape: 'spline', width: 0 }, name: 'DISK max', hoverinfo: 'none', legendgroup: 'DISK', showlegend: false },
-                { x: [], y: [], mode: 'lines', type: 'scatter', line: { shape: 'spline', color: '#7cdf8e' }, fill: 'tonexty', fillcolor: '#7cdf8e60', name: 'DISK', legendgroup: 'DISK' },
-                { x: [], y: [], mode: 'lines', type: 'scatter', line: { shape: 'spline', width: 0 }, fill: 'tonexty', fillcolor: '#7cdf8e60', name: 'DISK min', hoverinfo: 'none', legendgroup: 'DISK', showlegend: false },
+                { x: [], y: [], mode: 'lines', type: 'scatter', line: { shape: 'spline', color: Colors.DISK }, fill: 'tonexty', fillcolor: Colors.DISK + '60', name: 'DISK', legendgroup: 'DISK' },
+                { x: [], y: [], mode: 'lines', type: 'scatter', line: { shape: 'spline', width: 0 }, fill: 'tonexty', fillcolor: Colors.DISK + '60', name: 'DISK min', hoverinfo: 'none', legendgroup: 'DISK', showlegend: false },
                 
                 { x: [], y: [], mode: 'lines', type: 'scatter', line: { shape: 'spline', width: 0 }, name: 'SWAP max', hoverinfo: 'none', legendgroup: 'SWAP', showlegend: false },
-                { x: [], y: [], mode: 'lines', type: 'scatter', line: { shape: 'spline', color: '#575A4B' }, fill: 'tonexty', fillcolor: '#575A4B60', name: 'SWAP', legendgroup: 'SWAP' },
-                { x: [], y: [], mode: 'lines', type: 'scatter', line: { shape: 'spline', width: 0 }, fill: 'tonexty', fillcolor: '#575A4B60', name: 'SWAP min', hoverinfo: 'none', legendgroup: 'SWAP', showlegend: false },
+                { x: [], y: [], mode: 'lines', type: 'scatter', line: { shape: 'spline', color: Colors.SWAP }, fill: 'tonexty', fillcolor: Colors.SWAP + '60', name: 'SWAP', legendgroup: 'SWAP' },
+                { x: [], y: [], mode: 'lines', type: 'scatter', line: { shape: 'spline', width: 0 }, fill: 'tonexty', fillcolor: Colors.SWAP + '60', name: 'SWAP min', hoverinfo: 'none', legendgroup: 'SWAP', showlegend: false },
 
                 { x: [], y: [], mode: 'lines', type: 'scatter', line: { shape: 'spline', width: 0 }, name: 'RAM max', hoverinfo: 'none', legendgroup: 'RAM', showlegend: false },
-                { x: [], y: [], mode: 'lines', type: 'scatter', line: { shape: 'spline', color: '#ba9fd1' }, fill: 'tonexty', fillcolor: '#ba9fd160', name: 'RAM', legendgroup: 'RAM' },
-                { x: [], y: [], mode: 'lines', type: 'scatter', line: { shape: 'spline', width: 0 }, fill: 'tonexty', fillcolor: '#ba9fd160', name: 'RAM min', hoverinfo: 'none', legendgroup: 'RAM', showlegend: false },
+                { x: [], y: [], mode: 'lines', type: 'scatter', line: { shape: 'spline', color: Colors.RAM }, fill: 'tonexty', fillcolor: Colors.RAM + '60', name: 'RAM', legendgroup: 'RAM' },
+                { x: [], y: [], mode: 'lines', type: 'scatter', line: { shape: 'spline', width: 0 }, fill: 'tonexty', fillcolor: Colors.RAM + '60', name: 'RAM min', hoverinfo: 'none', legendgroup: 'RAM', showlegend: false },
                 
                 { x: [], y: [], mode: 'lines', type: 'scatter', line: { shape: 'spline', width: 0 }, name: 'CPU max', hoverinfo: 'none', legendgroup: 'CPU', showlegend: false },
-                { x: [], y: [], mode: 'lines', type: 'scatter', line: { shape: 'spline', color: '#f48f8d' }, fill: 'tonexty', fillcolor: '#f48f8d60', name: 'CPU', legendgroup: 'CPU' },
-                { x: [], y: [], mode: 'lines', type: 'scatter', line: { shape: 'spline', width: 0 }, fill: 'tonexty', fillcolor: '#f48f8d60', name: 'CPU min', hoverinfo: 'none', legendgroup: 'CPU', showlegend: false },
+                { x: [], y: [], mode: 'lines', type: 'scatter', line: { shape: 'spline', color: Colors.CPU }, fill: 'tonexty', fillcolor: Colors.CPU + '60', name: 'CPU', legendgroup: 'CPU' },
+                { x: [], y: [], mode: 'lines', type: 'scatter', line: { shape: 'spline', width: 0 }, fill: 'tonexty', fillcolor: Colors.CPU + '60', name: 'CPU min', hoverinfo: 'none', legendgroup: 'CPU', showlegend: false },
                 
                 { x: [], y: [], mode: 'lines', type: 'scatter', line: { shape: 'spline', width: 0 }, name: 'VRAM max', hoverinfo: 'none', legendgroup: 'VRAM', showlegend: false },
-                { x: [], y: [], mode: 'lines', type: 'scatter', line: { shape: 'spline', color: '#964A71' }, fill: 'tonexty', fillcolor: '#964A7160', name: 'VRAM', legendgroup: 'VRAM' },
-                { x: [], y: [], mode: 'lines', type: 'scatter', line: { shape: 'spline', width: 0 }, fill: 'tonexty', fillcolor: '#964A7160', name: 'VRAM min', hoverinfo: 'none', legendgroup: 'VRAM', showlegend: false },
+                { x: [], y: [], mode: 'lines', type: 'scatter', line: { shape: 'spline', color: Colors.VRAM }, fill: 'tonexty', fillcolor: Colors.VRAM + '60', name: 'VRAM', legendgroup: 'VRAM' },
+                { x: [], y: [], mode: 'lines', type: 'scatter', line: { shape: 'spline', width: 0 }, fill: 'tonexty', fillcolor: Colors.VRAM + '60', name: 'VRAM min', hoverinfo: 'none', legendgroup: 'VRAM', showlegend: false },
                 
 
                 { x: [], y: [], mode: 'lines', type: 'scatter', line: { shape: 'spline', width: 0 }, name: 'GPU max', hoverinfo: 'none', legendgroup: 'GPU', showlegend: false },
-                { x: [], y: [], mode: 'lines', type: 'scatter', line: { shape: 'spline', color: '#ffba7d' }, fill: 'tonexty', fillcolor: '#ffba7d60', name: 'GPU', legendgroup: 'GPU' },
-                { x: [], y: [], mode: 'lines', type: 'scatter', line: { shape: 'spline', width: 0 }, fill: 'tonexty', fillcolor: '#ffba7d60', name: 'GPU min', hoverinfo: 'none', legendgroup: 'GPU', showlegend: false },
+                { x: [], y: [], mode: 'lines', type: 'scatter', line: { shape: 'spline', color: Colors.GPU }, fill: 'tonexty', fillcolor: Colors.GPU + '60', name: 'GPU', legendgroup: 'GPU' },
+                { x: [], y: [], mode: 'lines', type: 'scatter', line: { shape: 'spline', width: 0 }, fill: 'tonexty', fillcolor: Colors.GPU + '60', name: 'GPU min', hoverinfo: 'none', legendgroup: 'GPU', showlegend: false },
                 
                 { /* This empty entry is needed */ },
                 { /* This empty entry is needed */ },
