@@ -6,12 +6,17 @@
 **/
 
 import * as React from 'react';
-import { Global } from '../Global';
-import { withStyles, Switch as OtherSwitch } from '@material-ui/core';
+import { DIV, Global } from '../Global';
+
+import { SxProps, Theme } from '@mui/system';
+import { Switch as OtherSwitch } from '@mui/material';
+import { withStyles } from '@mui/styles';
+
 import ExtraInfo from '../utils/ExtraInfo';
+import { Colors } from '../Colors';
 
 interface IProps {
-    style?: React.CSSProperties
+    sx?: SxProps<Theme>
     tooltip?: string
     getValue: () => boolean
     saveValue: (value: boolean) => void
@@ -24,13 +29,14 @@ interface IProps {
     color?: string
     onMouseOver?: (...args: any[]) => any
     onMouseOut?: (...args: any[]) => any
+    info?: JSX.Element
 }
 
 interface IState {
     value: boolean,
 }
 
-export const getStyledSwitch = (color: string = '#10A0F9') => {
+export const getStyledSwitch = (color: string = Colors.PRIMARY) => {
     return withStyles({
         root: {
             width: '42px',
@@ -79,25 +85,30 @@ export class Switch extends React.Component<IProps, IState> {
     public render = (): JSX.Element => {
         if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         return (
-            <div
-                style={Object.assign({
+            <DIV
+                sx={Object.assign({
                     display: 'inline-flex',
                     width: this.props.label ? '100%' : undefined,
                     padding: '6px 0px',
-                }, this.props.style)}
+                }, this.props.sx)}
                 ref={this.props.ref}
                 onMouseOver={this.props.onMouseOver}
                 onMouseOut={this.props.onMouseOut}
             >
                 {this.props.label && this.props.labelBefore && (
-                    <div style={{width: '100%', textAlign: 'left', margin: 'auto 12px'}}>
+                    <DIV sx={{
+                        width: this.props.labelWidth || '100%',
+                        textAlign: 'left',
+                        margin: 'auto 12px',
+                    }}>
                         {this.props.label}
-                    </div>
+                        {this.props.info}
+                    </DIV>
                 )}
                 <ExtraInfo reminder={this.props.tooltip || ''}>
-                    <div 
-                        style={{
-                        minWidth: this.props.labelWidth || 'unset',
+                    <DIV 
+                        sx={{
+                        minWidth: (this.props.labelBefore !== true && this.props.labelWidth) || 'unset',
                         lineHeight: '24px',
                         textAlign: 'center',
                         direction: this.props.flip ? 'rtl' : 'ltr'
@@ -111,14 +122,15 @@ export class Switch extends React.Component<IProps, IState> {
                             }}
                             disabled={this.props.disabled}
                         />
-                    </div>
+                    </DIV>
                 </ExtraInfo>
-                {this.props.label && (this.props.labelBefore == undefined || this.props.labelBefore == false) && (
-                    <div style={{width: '100%', textAlign: 'left', margin: 'auto 6px'}}>
-                        {this.props.label}                    
-                    </div>
+                {this.props.label && (this.props.labelBefore !== true) && (
+                    <DIV sx={{width: '100%', textAlign: 'left', margin: 'auto 6px'}}>
+                        {this.props.label}   
+                        {this.props.info}                 
+                    </DIV>
                 )}
-            </div>
+            </DIV>
         )
     }
 
