@@ -6,8 +6,9 @@
 **/
 
 import * as React from 'react'
+import { DIV, Global } from '../../Global';
+
 import InputArea from './InputArea'
-import { Global } from '../../Global';
 
 interface IProps {
     cell: any
@@ -22,9 +23,9 @@ export default class MarkdownCell extends React.Component<IProps, IState> {
     public render = (): JSX.Element => {
 		if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         return (
-            <div className='p-Widget lm-Widget jp-Cell jp-MarkdownCell jp-Notebook-cell'>
+            <DIV className='p-Widget lm-Widget jp-Cell jp-MarkdownCell jp-Notebook-cell'>
                 <InputArea cell={this.props.cell} metadata={this.props.metadata} renderInColor={this.props.renderInColor} />
-            </div>
+            </DIV>
         )
     }
 
