@@ -5,8 +5,6 @@
 **  To receive a copy of the licensing terms please write to contact@optumi.com or visit us at http://www.optumi.com.
 **/
 
-import { ServerConnection } from '@jupyterlab/services';
-import { Global } from '../Global';
 import { Update } from './Update';
 import { Machine } from './machine/Machine';
 import { FileMetadata } from '../components/deploy/fileBrowser/FileBrowser';
@@ -18,10 +16,8 @@ export enum Status {
 }
 
 export class Module {
-	private _sessionReady: boolean = false;
-
 	get sessionReady(): boolean {
-		return this._sessionReady;
+		return this._sessionToken != null;
 	}
 
 	private _lastPatch: number;
@@ -31,7 +27,6 @@ export class Module {
 	private readonly _uuid: string;
 
 	private _sessionToken: string;
-	private _sessionPort: string;
 
     private _machine: Machine;
     
@@ -49,7 +44,6 @@ export class Module {
         this._machine = machine;
 
 		this._output = output;
-		this._sessionReady = output.map(x => x.line.includes('Jupyter Server ') && x.line.includes(' is running at:')).includes(true);
 
 		this._updates = updates;
 		this._files = files;
@@ -73,10 +67,6 @@ export class Module {
 	get sessionToken(): string {
         return this._sessionToken;
 	}
-	
-	get sessionPort(): string {
-        return this._sessionPort;
-    }
 
     get machine(): Machine {
         return this._machine;
@@ -126,10 +116,6 @@ export class Module {
 			if (body.output.length > 0) updated = true;
 			for (let i = 0; i < body.output.length; i++) {
 				this._output.push(new Update(body.output[i], body.outputmod[i]));
-				if (body.output[i].includes('Jupyter Server ') && body.output[i].includes(' is running at:')) {
-					this._sessionReady = true;
-					window.open('http://' + window.location.hostname + ':' + this._sessionPort + '?token=' + this._sessionToken, '_blank');
-				}
 			}
 		}
 		if (body.notebook!= null) {
@@ -162,6 +148,7 @@ export class Module {
 				if (body.files[i] != '') {
 					updated = true
 					this._files.push({
+						created: body.filescrt[i],
 						last_modified: body.filesmod[i],
 						name: (body.files[i] as string).split('/').pop(),
 						path: body.files[i],
@@ -172,25 +159,20 @@ export class Module {
 				}
 			}
 		}
-		if (body.token != null) {
+		if (this._sessionToken == null && body.token != null) {
 			updated = true
 			this._sessionToken = body.token;
+			window.open('https://' + this.machine.dnsName + ':54321?token=' + this._sessionToken, '_blank');
 		}
 		if (body.updates != null) {
 			if (body.updates.length > 0) updated = true;
 			for (let i = 0; i < body.updates.length; i++) {
 				this._updates.push(new Update(body.updates[i], body.updatesmod[i]));
-				if (body.updatesmod[i] == "stop") {
-					this.stopSessionHandler();
-				} else if (body.updates[i] == "launched") {
-				} else if (body.updates[i] == "closed") {
-					this.stopSessionHandler();
-				}
 			}
 		}
 		if (body.machine != null) {
 			updated = true;
-			this._machine = Object.setPrototypeOf(body.machine, Machine.prototype);
+			this._machine = Machine.parse(body.machine);
 		}
 		if (body.monitoring != null) {
 			if (body.monitoring.length > 0) updated = true;
@@ -204,46 +186,4 @@ export class Module {
 		}
 		return updated;
 	}
-
-	public startSessionHandler() {
-		const settings = ServerConnection.makeSettings();
-		const url = settings.baseUrl + "optumi/connect-session";
-		const init: RequestInit = {
-			method: 'POST',
-			body: JSON.stringify({
-				module: this._uuid,
-			}),
-		};
-		ServerConnection.makeRequest(
-			url,
-			init, 
-			settings
-		).then((response: Response) => {
-			Global.handleResponse(response);
-			return response.json();
-		}).then((body: any) => {
-			if (body.port) {
-				this._sessionPort = body.port;
-			}
-		});
-	}
-
-	public stopSessionHandler() {
-		const settings = ServerConnection.makeSettings();
-		const url = settings.baseUrl + "optumi/disconnect-session";
-		const init: RequestInit = {
-			method: 'POST',
-			body: JSON.stringify({
-				module: this._uuid,
-			}),
-		};
-		ServerConnection.makeRequest(
-			url,
-			init, 
-			settings
-		).then((response: Response) => {
-			Global.handleResponse(response);
-			return response.text();
-		});
-	}
 }
