@@ -5,6 +5,12 @@
 **  To receive a copy of the licensing terms please write to contact@optumi.com or visit us at http://www.optumi.com.
 **/
 
+export enum JsonPayloadLevel {
+    INFO = "info",
+    WARNING = "warning",
+    ERROR = "error",
+}
+
 export class Update {
     public line: string;
     public modifier: string;
