@@ -7,7 +7,7 @@
 
 // import * as React from 'react'
 
-import { Global } from '../Global';
+import { Global, WhiteTextButton } from '../Global';
 
 import { ServerConnection } from '@jupyterlab/services';
 import { ISignal, Signal } from '@lumino/signaling';
@@ -21,17 +21,12 @@ import { FileTracker } from './FileTracker';
 import { FileChecker } from './FileChecker';
 import { EgressBucket } from './EgressBucket';
 import { StorageBucket } from './StorageBucket';
-// import { SnackbarKey } from 'notistack';
-// import { IconButton } from '@mui/material';
-// import { SubscribeButton } from '../core/SubscribeButton';
-// import { Close } from '@mui/icons-material';
-// import { Snackbar } from './Snackbar';
-// import FormatUtils from '../utils/FormatUtils';
-
-export enum BillingType {
-	CREDIT_BUCKET = 'credit bucket',
-	METERED_BILLING = 'metered subscription',
-}
+import FormatUtils from '../utils/FormatUtils';
+import { SnackbarKey } from 'notistack';
+import React from 'react';
+import { SubscribeButton } from '../core/SubscribeButton';
+import { Snackbar } from './Snackbar';
+import { CustomerState } from '../core/CustomerState';
 
 export class User {
 	
@@ -101,8 +96,7 @@ export class User {
             +responseData.maxMachines,
             +responseData.machinesCap,
             +responseData.userExpertise,
-            responseData.billingType as BillingType,
-			responseData.subscriptionActive,
+			responseData.customerState as CustomerState,
 			responseData.lastBillPaid,
 			responseData.billingCycleAnchor ? new Date(responseData.billingCycleAnchor) : null,
 			responseData.compressFilesEnabled,
@@ -124,7 +118,20 @@ export class User {
 			storageBuckets, 
 			+responseData.serviceFee,
 			responseData.trialStart ? new Date(responseData.trialStart) : null,
+			responseData.trialEnd ? new Date(responseData.trialEnd) : null,
+			responseData.subscriptionStart ? new Date(responseData.subscriptionStart) : null,
+			responseData.subscriptionEnd ? new Date(responseData.subscriptionEnd) : null,
 			+responseData.credit,
+			+responseData.runHistoryLength,
+			new Date(responseData.freeTrialEgressLimitDismissed),
+			new Date(responseData.freeTrialStorageLimitDismissed),
+			new Date(responseData.freeTrialCreditLimitDismissed),
+			new Date(responseData.freeTrialExpiredDismissed),
+			new Date(responseData.starterEgressLimitDismissed),
+			new Date(responseData.starterStorageLimitDismissed),
+			new Date(responseData.starterPopupDismissed),
+			new Date(responseData.freeTrialStartedPopupDismissed),
+			new Date(responseData.holdoverTimePopupDismissed),
             new AppTracker(),
 			new FileTracker(),
 			new FileChecker(),
@@ -177,8 +184,7 @@ export class User {
     private _maxMachines: number;
     private _machinesCap: number;
 	private _userExpertise: number;
-	private _billingType: BillingType;
-	private _subscriptionActive: boolean;
+	private _customerState: CustomerState;
 	private _lastBillPaid: boolean;
 	private _billingCycleAnchor: Date;
 	private _compressFilesEnabled: boolean;
@@ -200,8 +206,24 @@ export class User {
 	private _storageBuckets: StorageBucket[];
 	private _serviceFee: number;
 	private _trialStart: Date;
+	private _trialEnd: Date;
+	private _subscriptionStart: Date;
+	private _subscriptionEnd: Date;
 	private _credit: number;
+	private _runHistoryLength: number;
 
+	// Some markers to remember if a user has dismissed a warning snackbar
+    private _freeTrialEgressLimitDismissed: Date = new Date(0)
+    private _freeTrialStorageLimitDismissed: Date = new Date(0)
+    private _freeTrialCreditLimitDismissed: Date = new Date(0)
+    private _freeTrialExpiredDismissed: Date = new Date(0)
+    
+    private _starterEgressLimitDismissed: Date = new Date(0)
+    private _starterStorageLimitDismissed: Date = new Date(0)
+    private _starterPopupDismissed: Date = new Date(0)
+    private _freeTrialStartedPopupDismissed: Date = new Date(0)
+    private _holdoverTimePopupDismissed: Date = new Date(0)
+	
 	private _appTracker: AppTracker;
 	private _fileTracker: FileTracker;
 	private _fileChecker: FileChecker;
@@ -217,12 +239,16 @@ export class User {
         userRecommendations: number, maxRecommendations: number, recommendationsCap: number, 
         maxJobs: number, jobsCap: number, 
         maxMachines: number, machinesCap: number, 
-		userExpertise: number, billingType: BillingType, subscriptionActive: boolean, lastBillPaid: boolean, billingCycleAnchor: Date,
+		userExpertise: number, customerState: CustomerState, lastBillPaid: boolean, billingCycleAnchor: Date,
 		compressFilesEnabled: boolean, lastPage: number, 
 		stopJobPreventEnabled: boolean, deleteJobPreventEnabled: boolean, noRequirementsPreventEnabled: boolean, noFileUploadsPreventEnabled: boolean, 
 		startSessionPreventEnabled: boolean, notificationsEnabled: boolean, snapToInventoryEnabled: boolean, showMonitoringEnabled: boolean, showDownloadAllButtonEnabled: boolean,
 		autoAddOnsEnabled: boolean, egressTotal: number, egressLimit: number, egressMax: number,
-		egressBuckets: EgressBucket[], storageBuckets: StorageBucket[], serviceFee: number, trialStart: Date, credit: number,
+		egressBuckets: EgressBucket[], storageBuckets: StorageBucket[], serviceFee: number, 
+		trialStart: Date, trialEnd: Date, subscriptionStart: Date, subscriptionEnd: Date, 
+		credit: number, runHistoryLength: number,
+		freeTrialEgressLimitDismissed: Date, freeTrialStorageLimitDismissed: Date, freeTrialCreditLimitDismissed: Date, freeTrialExpiredDismissed: Date, 
+		starterEgressLimitDismissed: Date, starterStorageLimitDismissed: Date, starterPopupDismissed: Date, freeTrialStartedPopupDismissed: Date, holdoverTimePopupDismissed: Date,
 		appTracker: AppTracker, fileTracker: FileTracker, fileChecker: FileChecker, machines: Machines) {
         this._unsignedAgreement = unsignedAgreement === undefined ? true : unsignedAgreement;
         this._name = name;
@@ -249,8 +275,7 @@ export class User {
         this._machinesCap = machinesCap;
 
 		this._userExpertise = userExpertise;
-		this._billingType = billingType;
-		this._subscriptionActive = subscriptionActive;
+		this._customerState = customerState;
 		this._lastBillPaid = lastBillPaid;
 		this._billingCycleAnchor = billingCycleAnchor;
 
@@ -273,7 +298,22 @@ export class User {
 		this._storageBuckets = storageBuckets;
 		this._serviceFee = serviceFee;
 		this._trialStart = trialStart;
+		this._trialEnd = trialEnd;
+		this._subscriptionStart = subscriptionStart;
+		this._subscriptionEnd = subscriptionEnd;
 		this._credit = credit;
+		this._runHistoryLength = runHistoryLength;
+
+		this._freeTrialEgressLimitDismissed = freeTrialEgressLimitDismissed;
+		this._freeTrialStorageLimitDismissed = freeTrialStorageLimitDismissed;
+		this._freeTrialCreditLimitDismissed = freeTrialCreditLimitDismissed;
+		this._freeTrialExpiredDismissed = freeTrialExpiredDismissed;
+		
+		this._starterEgressLimitDismissed = starterEgressLimitDismissed;
+		this._starterStorageLimitDismissed = starterStorageLimitDismissed;
+		this._starterPopupDismissed = starterPopupDismissed;
+		this._freeTrialStartedPopupDismissed = freeTrialStartedPopupDismissed;
+		this._holdoverTimePopupDismissed = holdoverTimePopupDismissed;
 
 		this._appTracker = appTracker;
 		this._fileTracker = fileTracker;
@@ -281,6 +321,8 @@ export class User {
         this._machines = machines;
 
 		setTimeout(() => this.getUserInformation(), 10000);
+
+		this.generateSnackbars();
     }
     
     get unsignedAgreement(): boolean {
@@ -292,6 +334,7 @@ export class User {
 			return;
 		}
 		this._unsignedAgreement = unsignedAgreement;
+		this._userInformationChanged.emit(this);
 	}
 
 	get name(): string {
@@ -303,6 +346,7 @@ export class User {
 			return;
 		}
 		this._name = name;
+		this._userInformationChanged.emit(this);
 	}
 
 	get phoneNumber(): string {
@@ -313,8 +357,8 @@ export class User {
 		if (phoneNumber === this._phoneNumber) {
 			return;
 		}
-		this.setUserInformation("phoneNumber", phoneNumber);
 		this._phoneNumber = phoneNumber;
+		this.setUserInformation("phoneNumber", phoneNumber);
 	}
 
 	get deploySubMenu(): Page {
@@ -339,7 +383,7 @@ export class User {
 			return;
 		}
 		this._intent = intent;
-		this.setUserInformation("intent", intent.toString());
+		this.setUserInformation("intent", intent);
 	}
 
 	get userBudget(): number {
@@ -351,7 +395,7 @@ export class User {
 			return;
 		}
 		this._userBudget = userBudget;
-		this.setUserInformation("userBudget", userBudget.toString());
+		this.setUserInformation("userBudget", userBudget);
     }
     
     get maxBudget(): number {
@@ -363,7 +407,7 @@ export class User {
 			return;
 		}
 		this._maxBudget = maxBudget;
-		this.setUserInformation("maxBudget", maxBudget.toString());
+		this.setUserInformation("maxBudget", maxBudget);
     }
     
     get budgetCap(): number {
@@ -379,7 +423,7 @@ export class User {
 			return;
 		}
 		this._userRate = userRate;
-		this.setUserInformation("userRate", userRate.toString());
+		this.setUserInformation("userRate", userRate);
     }
     
     get maxRate(): number {
@@ -391,7 +435,7 @@ export class User {
 			return;
 		}
 		this._maxRate = maxRate;
-		this.setUserInformation("maxRate", maxRate.toString());
+		this.setUserInformation("maxRate", maxRate);
     }
     
     get rateCap(): number {
@@ -407,7 +451,7 @@ export class User {
 			return;
 		}
 		this._userAggregateRate = userAggregateRate;
-		this.setUserInformation("userAggregateRate", userAggregateRate.toString());
+		this.setUserInformation("userAggregateRate", userAggregateRate);
     }
     
     get maxAggregateRate(): number {
@@ -419,7 +463,7 @@ export class User {
 			return;
 		}
 		this._maxAggregateRate = maxAggregateRate;
-		this.setUserInformation("maxAggregateRate", maxAggregateRate.toString());
+		this.setUserInformation("maxAggregateRate", maxAggregateRate);
     }
     
     get aggregateRateCap(): number {
@@ -435,7 +479,7 @@ export class User {
 			return;
 		}
 		this._userHoldoverTime = userHoldoverTime;
-		this.setUserInformation("userHoldoverTime", userHoldoverTime.toString());
+		this.setUserInformation("userHoldoverTime", userHoldoverTime);
     }
     
     get maxHoldoverTime(): number {
@@ -447,7 +491,7 @@ export class User {
 			return;
 		}
 		this._maxHoldoverTime = maxHoldoverTime;
-		this.setUserInformation("maxHoldoverTime", maxHoldoverTime.toString());
+		this.setUserInformation("maxHoldoverTime", maxHoldoverTime);
     }
     
     get holdoverTimeCap(): number {
@@ -462,7 +506,7 @@ export class User {
 			return;
 		}
 		this._userRecommendations = userRecommendations;
-		this.setUserInformation("userRecommendations", userRecommendations.toString());
+		this.setUserInformation("userRecommendations", userRecommendations);
     }
     
     get maxRecommendations(): number {
@@ -474,7 +518,7 @@ export class User {
 			return;
 		}
 		this._maxRecommendations = maxRecommendations;
-		this.setUserInformation("maxRecommendations", maxRecommendations.toString());
+		this.setUserInformation("maxRecommendations", maxRecommendations);
     }
     
     get recommendationsCap(): number {
@@ -489,7 +533,7 @@ export class User {
 			return;
 		}
 		this._maxJobs = maxJobs;
-		this.setUserInformation("maxJobs", maxJobs.toString());
+		this.setUserInformation("maxJobs", maxJobs);
     }
 
     get jobsCap(): number {
@@ -505,7 +549,7 @@ export class User {
 			return;
 		}
 		this._maxMachines = maxMachines;
-		this.setUserInformation("maxMachines", maxMachines.toString());
+		this.setUserInformation("maxMachines", maxMachines);
     }
     
     get machinesCap(): number {
@@ -516,12 +560,29 @@ export class User {
 		return this._userExpertise;
 	}
 
-	get billingType(): BillingType {
-		return this._billingType;
+	get customerState(): CustomerState {
+		return this._customerState;
 	}
 
-	get subscriptionActive(): boolean {
-		return this._subscriptionActive;
+	// NOTE: This function simply allows us to update the state of a user before we get confirmation from the controller, so it is an extension change only
+	set customerState(customerState: CustomerState) {
+		if (customerState === this._customerState) {
+			return;
+		}
+		this._customerState = customerState;
+		this._userInformationChanged.emit(this);
+	}
+
+	public isSubscribed() {
+		switch (this._customerState) {
+			case CustomerState.STARTER:
+				return true;
+			case CustomerState.FREE_TRIAL:
+			case CustomerState.FREE_TRIAL_ENDED:
+			case CustomerState.INIT:
+			case CustomerState.SUBSCRIPTION_CANCELED:
+		}
+		return false;
 	}
 
 	get lastBillPaid(): boolean {
@@ -541,7 +602,7 @@ export class User {
 			return;
 		}
 		this._compressFilesEnabled = compressFilesEnabled;
-		this.setUserInformation("compressFilesEnabled", compressFilesEnabled.toString());
+		this.setUserInformation("compressFilesEnabled", compressFilesEnabled);
 	}
 	
 	get lastPage(): number {
@@ -553,7 +614,7 @@ export class User {
 			return;
 		}
 		this._lastPage = lastPage;
-		this.setUserInformation("lastPage", lastPage.toString());
+		this.setUserInformation("lastPage", lastPage);
 	}
 	
 	get stopJobPreventEnabled(): boolean {
@@ -565,7 +626,7 @@ export class User {
 			return;
 		}
 		this._stopJobPreventEnabled = stopJobPreventEnabled;
-		this.setUserInformation("stopJobPreventEnabled", stopJobPreventEnabled.toString());
+		this.setUserInformation("stopJobPreventEnabled", stopJobPreventEnabled);
 	}
 
 	get deleteJobPreventEnabled(): boolean {
@@ -577,7 +638,7 @@ export class User {
 			return;
 		}
 		this._deleteJobPreventEnabled = deleteJobPreventEnabled;
-		this.setUserInformation("deleteJobPreventEnabled", deleteJobPreventEnabled.toString());
+		this.setUserInformation("deleteJobPreventEnabled", deleteJobPreventEnabled);
 	}
 
 	get noRequirementsPreventEnabled(): boolean {
@@ -589,7 +650,7 @@ export class User {
 			return;
 		}
 		this._noRequirementsPreventEnabled = noRequirementsPreventEnabled;
-		this.setUserInformation("noRequirementsPreventEnabled", noRequirementsPreventEnabled.toString());
+		this.setUserInformation("noRequirementsPreventEnabled", noRequirementsPreventEnabled);
 	}
 
 	get noFileUploadsPreventEnabled(): boolean {
@@ -601,7 +662,7 @@ export class User {
 			return;
 		}
 		this._noFileUploadsPreventEnabled = noFileUploadsPreventEnabled;
-		this.setUserInformation("noFileUploadsPreventEnabled", noFileUploadsPreventEnabled.toString());
+		this.setUserInformation("noFileUploadsPreventEnabled", noFileUploadsPreventEnabled);
 	}
 	
 	get startSessionPreventEnabled(): boolean {
@@ -613,7 +674,7 @@ export class User {
 			return;
 		}
 		this._startSessionPreventEnabled = startSessionPreventEnabled;
-		this.setUserInformation("startSessionPreventEnabled", startSessionPreventEnabled.toString());
+		this.setUserInformation("startSessionPreventEnabled", startSessionPreventEnabled);
 	}
 
 	get notificationsEnabled(): boolean {
@@ -625,7 +686,7 @@ export class User {
 			return;
 		}
 		this._notificationsEnabled = notificationsEnabled;
-		this.setUserInformation("notificationsEnabled", notificationsEnabled.toString());
+		this.setUserInformation("notificationsEnabled", notificationsEnabled);
 	}
 
 	get snapToInventoryEnabled(): boolean {
@@ -637,7 +698,7 @@ export class User {
 			return;
 		}
 		this._snapToInventoryEnabled = snapToInventoryEnabled;
-		this.setUserInformation("snapToInventoryEnabled", snapToInventoryEnabled.toString());
+		this.setUserInformation("snapToInventoryEnabled", snapToInventoryEnabled);
 	}
 
 	get showMonitoringEnabled(): boolean {
@@ -653,7 +714,7 @@ export class User {
 			return;
 		}
 		this._autoAddOnsEnabled = autoAddOnsEnabled;
-		this.setUserInformation("autoAddOnsEnabled", autoAddOnsEnabled.toString());
+		this.setUserInformation("autoAddOnsEnabled", autoAddOnsEnabled);
 	}
 
 	get showDownloadAllButtonEnabled(): boolean {
@@ -693,13 +754,147 @@ export class User {
 			return;
 		}
 		this._trialStart = trialStart;
-		this.setUserInformation("trialStart", trialStart.toISOString());
+		// We don't actually allow the user to pick the trial start date, so pass null here
+		this.setUserInformation("trialStart", null);
+	}
+
+	get trialEnd(): Date {
+		return this._trialEnd;
+	}
+
+	get subscriptionStart(): Date {
+		return this._subscriptionStart;
+	}
+
+	get subscriptionEnd(): Date {
+		return this._subscriptionEnd;
 	}
 
 	get credit(): number {
 		return this._credit;
 	}
 
+	get runHistoryLength(): number {
+		return this._runHistoryLength;
+	}
+
+	get freeTrialEgressLimitDismissed(): Date {
+		return this._freeTrialEgressLimitDismissed;
+	}
+
+	set freeTrialEgressLimitDismissed(freeTrialEgressLimitDismissed: Date) {
+		if (freeTrialEgressLimitDismissed === this._freeTrialEgressLimitDismissed) {
+			return;
+		}
+		this._freeTrialEgressLimitDismissed = freeTrialEgressLimitDismissed;
+		// We don't actually allow the user to pick the trial start date, so pass null here
+		this.setUserInformation("freeTrialEgressLimitDismissed", null);
+	}
+
+	get freeTrialStorageLimitDismissed(): Date {
+		return this._freeTrialStorageLimitDismissed;
+	}
+
+	set freeTrialStorageLimitDismissed(freeTrialStorageLimitDismissed: Date) {
+		if (freeTrialStorageLimitDismissed === this._freeTrialStorageLimitDismissed) {
+			return;
+		}
+		this._freeTrialStorageLimitDismissed = freeTrialStorageLimitDismissed;
+		// We don't actually allow the user to pick the trial start date, so pass null here
+		this.setUserInformation("freeTrialStorageLimitDismissed", null);
+	}
+
+	get freeTrialCreditLimitDismissed(): Date {
+		return this._freeTrialCreditLimitDismissed;
+	}
+
+	set freeTrialCreditLimitDismissed(freeTrialCreditLimitDismissed: Date) {
+		if (freeTrialCreditLimitDismissed === this._freeTrialCreditLimitDismissed) {
+			return;
+		}
+		this._freeTrialCreditLimitDismissed = freeTrialCreditLimitDismissed;
+		// We don't actually allow the user to pick the trial start date, so pass null here
+		this.setUserInformation("freeTrialCreditLimitDismissed", null);
+	}
+
+    get freeTrialExpiredDismissed(): Date {
+		return this._freeTrialExpiredDismissed;
+	}
+
+	set freeTrialExpiredDismissed(freeTrialExpiredDismissed: Date) {
+		if (freeTrialExpiredDismissed === this._freeTrialExpiredDismissed) {
+			return;
+		}
+		this._freeTrialExpiredDismissed = freeTrialExpiredDismissed;
+		// We don't actually allow the user to pick the trial start date, so pass null here
+		this.setUserInformation("freeTrialExpiredDismissed", null);
+	}
+
+	get starterEgressLimitDismissed(): Date {
+		return this._starterEgressLimitDismissed;
+	}
+
+	set starterEgressLimitDismissed(starterEgressLimitDismissed: Date) {
+		if (starterEgressLimitDismissed === this._starterEgressLimitDismissed) {
+			return;
+		}
+		this._starterEgressLimitDismissed = starterEgressLimitDismissed;
+		// We don't actually allow the user to pick the trial start date, so pass null here
+		this.setUserInformation("starterEgressLimitDismissed", null);
+	}
+
+	get starterStorageLimitDismissed(): Date {
+		return this._starterStorageLimitDismissed;
+	}
+
+	set starterStorageLimitDismissed(starterStorageLimitDismissed: Date) {
+		if (starterStorageLimitDismissed === this._starterStorageLimitDismissed) {
+			return;
+		}
+		this._starterStorageLimitDismissed = starterStorageLimitDismissed;
+		// We don't actually allow the user to pick the trial start date, so pass null here
+		this.setUserInformation("starterStorageLimitDismissed", null);
+	}
+
+	get starterPopupDismissed(): Date {
+		return this._starterPopupDismissed;
+	}
+
+	set starterPopupDismissed(starterPopupDismissed: Date) {
+		if (starterPopupDismissed === this._starterPopupDismissed) {
+			return;
+		}
+		this._starterPopupDismissed = starterPopupDismissed;
+		// We don't actually allow the user to pick the trial start date, so pass null here
+		this.setUserInformation("starterPopupDismissed", null);
+	}
+
+	get freeTrialStartedPopupDismissed(): Date {
+		return this._freeTrialStartedPopupDismissed;
+	}
+
+	set freeTrialStartedPopupDismissed(freeTrialStartedPopupDismissed: Date) {
+		if (freeTrialStartedPopupDismissed === this._freeTrialStartedPopupDismissed) {
+			return;
+		}
+		this._freeTrialStartedPopupDismissed = freeTrialStartedPopupDismissed;
+		// We don't actually allow the user to pick the trial start date, so pass null here
+		this.setUserInformation("freeTrialStartedPopupDismissed", null);
+	}
+
+	get holdoverTimePopupDismissed(): Date {
+		return this._holdoverTimePopupDismissed;
+	}
+
+	set holdoverTimePopupDismissed(holdoverTimePopupDismissed: Date) {
+		if (holdoverTimePopupDismissed === this._holdoverTimePopupDismissed) {
+			return;
+		}
+		this._holdoverTimePopupDismissed = holdoverTimePopupDismissed;
+		// We don't actually allow the user to pick the trial start date, so pass null here
+		this.setUserInformation("holdoverTimePopupDismissed", null);
+	}
+
 	get fileTracker(): FileTracker {
 		return this._fileTracker;
 	}
@@ -722,7 +917,7 @@ export class User {
 	get machines(): Machines {
 		return this._machines;
 	}
-
+		
 	public synchronize(responseData: any) {
 		// Add apps from user information if they don't already exist
 		if (responseData.jobs) {
@@ -789,24 +984,49 @@ export class User {
 				if (body.maxMachines) this._maxMachines = +body.maxMachines
 				if (body.machinesCap) this._machinesCap = +body.machinesCap
 				if (body.userExpertise) this._userExpertise = +body.userExpertise
-				if (body.billingType) this._billingType = body.billingType as BillingType
-				if (body.subscriptionActive) this._subscriptionActive = body.subscriptionActive
-				if (body.lastBillPaid) this._lastBillPaid = body.lastBillPaid
+				if (body.customerState) this._customerState = body.customerState as CustomerState
+				if (body.lastBillPaid != undefined) this._lastBillPaid = body.lastBillPaid
 				if (body.billingCycleAnchor) this._billingCycleAnchor = new Date(body.billingCycleAnchor)
-				if (body.compressFilesEnabled) this._compressFilesEnabled = body.compressFilesEnabled
+				if (body.compressFilesEnabled != undefined) this._compressFilesEnabled = body.compressFilesEnabled
 				if (body.lastPage) this._lastPage = body.lastPage
-				if (body.stopJobPreventEnabled) this._stopJobPreventEnabled = body.stopJobPreventEnabled
-				if (body.deleteJobPreventEnabled) this._deleteJobPreventEnabled = body.deleteJobPreventEnabled
-				if (body.noRequirementsPreventEnabled) this._noRequirementsPreventEnabled = body.noRequirementsPreventEnabled
-				if (body.noFileUploadsPreventEnabled) this._noFileUploadsPreventEnabled = body.noFileUploadsPreventEnabled
-				if (body.startSessionPreventEnabled) this._startSessionPreventEnabled = body.startSessionPreventEnabled
-				if (body.notificationsEnabled) this._notificationsEnabled = body.notificationsEnabled
-				if (body.snapToInventoryEnabled) this._snapToInventoryEnabled = body.snapToInventoryEnabled
-				if (body.showMonitoringEnabled) this._showMonitoringEnabled = body.showMonitoringEnabled
-				if (body.showDownloadAllButtonEnabled) this._showDownloadAllButtonEnabled = body.showDownloadAllButtonEnabled
-				if (body.autoAddOnsEnabled) this._autoAddOnsEnabled = body.autoAddOnsEnabled
+				if (body.stopJobPreventEnabled != undefined) this._stopJobPreventEnabled = body.stopJobPreventEnabled
+				if (body.deleteJobPreventEnabled != undefined) this._deleteJobPreventEnabled = body.deleteJobPreventEnabled
+				if (body.noRequirementsPreventEnabled != undefined) this._noRequirementsPreventEnabled = body.noRequirementsPreventEnabled
+				if (body.noFileUploadsPreventEnabled != undefined) this._noFileUploadsPreventEnabled = body.noFileUploadsPreventEnabled
+				if (body.startSessionPreventEnabled != undefined) this._startSessionPreventEnabled = body.startSessionPreventEnabled
+				if (body.notificationsEnabled != undefined) this._notificationsEnabled = body.notificationsEnabled
+				if (body.snapToInventoryEnabled != undefined) this._snapToInventoryEnabled = body.snapToInventoryEnabled
+				if (body.showMonitoringEnabled != undefined) this._showMonitoringEnabled = body.showMonitoringEnabled
+				if (body.showDownloadAllButtonEnabled != undefined) this._showDownloadAllButtonEnabled = body.showDownloadAllButtonEnabled
+				if (body.autoAddOnsEnabled != undefined) this._autoAddOnsEnabled = body.autoAddOnsEnabled
 				if (body.egressTotal) this._egressTotal = +body.egressTotal
-				if (body.egressLimit) this._egressLimit = +body.egressLimit
+				if (body.egressLimit) {
+					if (this._egressLimit != 0 && +body.egressLimit > this._egressLimit) {
+						const action = (key: SnackbarKey) => (
+                            <>
+                                <WhiteTextButton
+                                    onClick={() => {
+                                        Global.followLink(Global.Target.SettingsPopup.BillingTab)
+                                    }}
+                                >
+                                    View upgrade settings
+                                </WhiteTextButton>
+                                <WhiteTextButton
+                                    onClick={() => {
+                                        Global.snackbarClose.emit(key) 
+                                    }}
+                                >
+                                    Dismiss
+                                </WhiteTextButton>
+                            </>
+                        );
+                        Global.snackbarEnqueue.emit(new Snackbar(
+                            'Your egress has been upgraded to ' + FormatUtils.styleCapacityUnitValue()(+body.egressLimit),
+                            { variant: 'success', persist: true, action }
+                        ));
+                    }
+					this._egressLimit = +body.egressLimit
+				}
 				if (body.egressMax) this._egressMax = +body.egressMax
 				if (body.egressBuckets) {
 					var egressBuckets = []
@@ -825,35 +1045,94 @@ export class User {
 				if (body.egressMax) this._egressMax = +body.egressMax
 				if (body.serviceFee) this._serviceFee = +body.serviceFee
 				if (body.trialStart) this._trialStart = new Date(body.trialStart)
+				if (body.trialEnd) this._trialEnd = new Date(body.trialEnd)
+				if (body.subscriptionStart) this._subscriptionStart = new Date(body.subscriptionStart)
+				if (body.subscriptionEnd) this._subscriptionEnd = new Date(body.subscriptionEnd)
 				if (body.credit) this._credit = +body.credit
-				this._userInformationChanged.emit(this);
+				if (body.runHistoryLength) this._runHistoryLength = +body.runHistoryLength
 
-				// if (this._egressTotal >= this._egressLimit) {
-					// const action = (key: SnackbarKey) => (
-					// 	<>
-					// 		<SubscribeButton variant='outlined' color='secondary'/>
-					// 		<IconButton
-					// 			onClick={() => { Global.snackbarClose.emit(key) }}
-					// 			sx={{padding: '3px'}}
-					// 		>
-					// 			<Close sx={{ color: 'white' }}/>
-					// 		</IconButton>
-					// 	</>
-					// );
-					// Global.snackbarEnqueue.emit(new Snackbar(
-					// 	'You have hit the ' + FormatUtils.styleCapacityUnitValue()(this._egressLimit) + ' egress limit',
-					// 	{ variant: 'error', persist: true, key: new Date().toISOString(), action }
-					// ));
-				// }
+				if (body.freeTrialEgressLimitDismissed) this._freeTrialEgressLimitDismissed = new Date(body.freeTrialEgressLimitDismissed);
+				if (body.freeTrialStorageLimitDismissed) this._freeTrialStorageLimitDismissed = new Date(body.freeTrialStorageLimitDismissed);
+				if (body.freeTrialCreditLimitDismissed) this._freeTrialCreditLimitDismissed = new Date(body.freeTrialCreditLimitDismissed);
+				if (body.freeTrialExpiredDismissed) this._freeTrialExpiredDismissed = new Date(body.freeTrialExpiredDismissed);
+				
+				if (body.starterEgressLimitDismissed) this._starterEgressLimitDismissed = new Date(body.starterEgressLimitDismissed);
+				if (body.starterStorageLimitDismissed) this._starterStorageLimitDismissed = new Date(body.starterStorageLimitDismissed);
+				if (body.starterPopupDismissed) this._starterPopupDismissed = new Date(body.starterPopupDismissed);
+				if (body.freeTrialStartedPopupDismissed) this._freeTrialStartedPopupDismissed = new Date(body.freeTrialStartedPopupDismissed);
+				if (body.holdoverTimePopupDismissed) this._holdoverTimePopupDismissed = new Date(body.holdoverTimePopupDismissed);
+
+				this._userInformationChanged.emit(this);
+				this.generateSnackbars();
 			}
 			setTimeout(() => this.getUserInformation(), 10000);
-		}, () => {
+		}, (err) => {
 			// Make sure we still poll even if we encounter an error
+			console.error(err)
 			setTimeout(() => this.getUserInformation(), 10000);
 		});
 	}
 
-	private setUserInformation(param: string, value: string) {
+	private generateSnackbars() {
+		const now = new Date()
+		if (!this.isSubscribed()) {
+			// freeTrialEgressLimit
+			if ((now.getTime() - this.freeTrialEgressLimitDismissed.getTime() > Global.dismissalTimeout) && this.egressTotal >= this.egressLimit) {
+				const action = (key: SnackbarKey) => (
+					<>
+						<SubscribeButton
+							variant='whiteText'
+							color='secondary'
+							onClick={() => {
+								this.freeTrialEgressLimitDismissed = new Date();
+							}}
+						/>
+						<WhiteTextButton
+							onClick={() => {
+								this.freeTrialEgressLimitDismissed = new Date();
+								Global.snackbarClose.emit(key) 
+							}}
+						>
+							Dismiss
+						</WhiteTextButton>
+					</>
+				);
+				Global.snackbarEnqueue.emit(new Snackbar(
+					'You have reached the ' + FormatUtils.styleCapacityUnitValue()(this._egressLimit) + ' egress limit',
+					{ variant: 'error', persist: true, action }
+				));
+			}
+		} else {
+			// starterEgressLimit
+			if ((now.getTime() - this.starterEgressLimitDismissed.getTime() > Global.dismissalTimeout) && !this.autoAddOnsEnabled && this.egressTotal >= this.egressLimit) {
+				const action = (key: SnackbarKey) => (
+					<>
+						<WhiteTextButton
+							onClick={() => {
+								Global.followLink(Global.Target.SettingsPopup.BillingTab)
+							}}
+						>
+							View upgrade settings
+						</WhiteTextButton>
+						<WhiteTextButton
+							onClick={() => {
+								this.starterEgressLimitDismissed = new Date();
+								Global.snackbarClose.emit(key) 
+							}}
+						>
+							Dismiss
+						</WhiteTextButton>
+					</>
+				);
+				Global.snackbarEnqueue.emit(new Snackbar(
+					'You have reached the ' + FormatUtils.styleCapacityUnitValue()(this._egressLimit) + ' egress limit',
+					{ variant: 'error', persist: true, action, }
+				));
+			}
+		}
+	}
+
+	private setUserInformation(param: string, value: any) {
 		const settings = ServerConnection.makeSettings();
 		const url = settings.baseUrl + "optumi/set-user-information";
 		const init = {
@@ -872,24 +1151,4 @@ export class User {
 		});
 		this._userInformationChanged.emit(this);
 	}
-
-	public changePassword(loginName: string, oldPassword: string, newPassword: string) {
-		const settings = ServerConnection.makeSettings();
-		const url = settings.baseUrl + "optumi/change-password";
-		const init = {
-			method: 'POST',
-			body: JSON.stringify({
-				'loginName': loginName,
-				'oldPassword': oldPassword,
-				'newPassword': newPassword,
-			})
-		};
-		return ServerConnection.makeRequest(
-			url,
-			init, 
-			settings
-		).then((response: Response) => {
-			Global.handleResponse(response);
-		});	
-	}
 }
