@@ -185,20 +185,7 @@ export class IdentityMachineComponent extends React.Component<IProps, IState> {
             <ExtraInfo reminder={title}>
                 <DIV
                     sx={{display: 'inline-flex', width: '262px', }}
-                    title={machine.graphicsNumCards > 0 ? 
-`GPU: ` + machine.graphicsNumCards + ' ' + machine.graphicsCardType + `
-vRAM: ` + FormatUtils.styleCapacityUnitValue()(machine.graphicsMemory) + `
-CPU: ` + (machine.computeCores[1] == machine.computeCores[2] ? Math.round(machine.computeCores[1] * 100) / 100 : Math.round(machine.computeCores[1] * 100) / 100 + `-` + Math.round(machine.computeCores[2] * 100) / 100) + ` cores
-RAM: ` + FormatUtils.styleCapacityUnitValue()(machine.memorySize) + `
-Disk: ` + FormatUtils.styleCapacityUnitValue()(machine.storageSize) + `
-GPU Rating: ` + ((machine.graphicsScore / machines.graphicsScoreMax) * 100).toFixed() + `%
-CPU Rating: ` + (machine.computeScore[1] == machine.computeScore[2] ? (machine.computeScore[1] / machines.computeScoreMax * 100).toFixed() : (machine.computeScore[1] / machines.computeScoreMax * 100).toFixed() + `-` + (machine.computeScore[2] / machines.computeScoreMax * 100).toFixed()) + `%`
-:  
-`CPU: ` + (machine.computeCores[1] == machine.computeCores[2] ? Math.round(machine.computeCores[1] * 100) / 100 : Math.round(machine.computeCores[1] * 100) / 100 + `-` + Math.round(machine.computeCores[2] * 100) / 100) + ` cores
-RAM: ` + FormatUtils.styleCapacityUnitValue()(machine.memorySize) + `
-Disk: ` + FormatUtils.styleCapacityUnitValue()(machine.storageSize) + `
-CPU Rating: ` + (machine.computeScore[1] == machine.computeScore[2] ? (machine.computeScore[1] / machines.computeScoreMax * 100).toFixed() : (machine.computeScore[1] / machines.computeScoreMax * 100).toFixed() + `-` + (machine.computeScore[2] / machines.computeScoreMax * 100).toFixed()) + `%`
-}
+                    title={machine.getDetails()}
                 >
                     <DIV sx={{width: '100%', lineHeight: '9px', textAlign: 'left'}}>
                         {Global.expertModeSelected ? (
