@@ -34,7 +34,6 @@ const color = Colors.SECONDARY
 
 const StyledButton = withStyles({
     root: {
-        margin: '12px 18px',
         padding: '8px',
         // height: '28px',
         border: '1px solid ' + color + '80',
@@ -44,6 +43,7 @@ const StyledButton = withStyles({
         position: 'relative',
         fontWeight: 'normal',
         height: 'fit-content',
+        color: 'var(--jp-ui-font-color1)',
     },
 }) (Button)
 
@@ -243,24 +243,32 @@ export class MachinePreviewComponent extends React.Component<IProps, IState> {
                                                         {row.map((bucket) => (
                                                             <DIV sx={{
                                                                 width: 'min-content', 
+                                                                padding: '6px 9px',
                                                             }}>
                                                                 {bucket.map((m) => (
-                                                                    <StyledButton
-                                                                        id={m.name}
-                                                                        style={{display: 'block', border: !(m instanceof NoMachine) && this.state.selectedMachine == m.name ? '1px solid ' + color : ''}}
-                                                                        sx={{backgroundColor: !(m instanceof NoMachine) && this.state.selectedMachine == m.name ? color + '40' : '',}}
-                                                                        onClick={() => this.handleMachineChange(m)}
-                                                                        disabled={m instanceof NoMachine}
-                                                                    >
-                                                                        {m instanceof NoMachine ? <DIV sx={{height: '68px', width: '262px'}}/> : (
-                                                                            <>
-                                                                                {m.getIdentityComponent()}
-                                                                                <DIV sx={{width: '100%', fontWeight: 'bold',  margin: '8px 0px 0px', fontSize: FONT_SIZE, lineHeight: FONT_SIZE, textAlign: 'center'}}>
-                                                                                    Rate: {FormatUtils.styleRateUnitValue()(m.rate || 0)}
-                                                                                </DIV>
-                                                                            </>
-                                                                        )}
-                                                                    </StyledButton>
+                                                                    <DIV sx={{
+                                                                        padding:  !(m instanceof NoMachine) && this.state.selectedMachine == m.name ? '5px 8px' : '6px 9px',
+                                                                    }}>
+                                                                        <StyledButton
+                                                                            id={m.name}
+                                                                            style={{
+                                                                                display: 'block', 
+                                                                                border: !(m instanceof NoMachine) && this.state.selectedMachine == m.name ? '2px solid ' + color : '',
+                                                                            }}
+                                                                            sx={{backgroundColor: !(m instanceof NoMachine) && this.state.selectedMachine == m.name ? color + '40' : '',}}
+                                                                            onClick={() => this.handleMachineChange(m)}
+                                                                            disabled={m instanceof NoMachine}
+                                                                        >
+                                                                            {m instanceof NoMachine ? <DIV sx={{height: '68px', width: '262px'}}/> : (
+                                                                                <>
+                                                                                    {m.getIdentityComponent()}
+                                                                                    <DIV sx={{width: '100%', fontWeight: 'bold',  margin: '8px 0px 0px', fontSize: FONT_SIZE, lineHeight: FONT_SIZE, textAlign: 'center'}}>
+                                                                                        Rate: {FormatUtils.styleRateUnitValue()(m.rate || 0)}
+                                                                                    </DIV>
+                                                                                </>
+                                                                            )}
+                                                                        </StyledButton>
+                                                                    </DIV>
                                                                 ))}
                                                             </DIV>
                                                         ))}
@@ -305,24 +313,32 @@ export class MachinePreviewComponent extends React.Component<IProps, IState> {
                                                         {row.map((bucket) => (
                                                             <DIV sx={{
                                                                 width: 'min-content', 
+                                                                padding: '6px 9px',
                                                             }}>
                                                                 {bucket.map((m) => (
-                                                                    <StyledButton
-                                                                        id={m.name}
-                                                                        style={{display: 'block', border: !(m instanceof NoMachine) && this.state.selectedMachine == m.name ? '1px solid ' + color : ''}}
-                                                                        sx={{backgroundColor: !(m instanceof NoMachine) && this.state.selectedMachine == m.name ? color + '40' : '',}}
-                                                                        onClick={() => this.handleMachineChange(m)}
-                                                                        disabled={m instanceof NoMachine}
-                                                                    >
-                                                                        {m instanceof NoMachine ? <DIV sx={{height: '52px', width: '262px'}}/> : (
-                                                                            <>
-                                                                                {m.getIdentityComponent()}
-                                                                                <DIV sx={{width: '100%', fontWeight: 'bold',  margin: '8px 0px 0px', fontSize: FONT_SIZE, lineHeight: FONT_SIZE, textAlign: 'center'}}>
-                                                                                    Rate: {FormatUtils.styleRateUnitValue()(m.rate || 0)}
-                                                                                </DIV>
-                                                                            </>
-                                                                        )}
-                                                                    </StyledButton>
+                                                                    <DIV sx={{
+                                                                        padding:  !(m instanceof NoMachine) && this.state.selectedMachine == m.name ? '5px 8px' : '6px 9px',
+                                                                    }}>
+                                                                        <StyledButton
+                                                                            id={m.name}
+                                                                            style={{
+                                                                                display: 'block', 
+                                                                                border: !(m instanceof NoMachine) && this.state.selectedMachine == m.name ? '2px solid ' + color : '',
+                                                                            }}
+                                                                            sx={{backgroundColor: !(m instanceof NoMachine) && this.state.selectedMachine == m.name ? color + '40' : '',}}
+                                                                            onClick={() => this.handleMachineChange(m)}
+                                                                            disabled={m instanceof NoMachine}
+                                                                        >
+                                                                            {m instanceof NoMachine ? <DIV sx={{height: '52px', width: '262px'}}/> : (
+                                                                                <>
+                                                                                    {m.getIdentityComponent()}
+                                                                                    <DIV sx={{width: '100%', fontWeight: 'bold',  margin: '8px 0px 0px', fontSize: FONT_SIZE, lineHeight: FONT_SIZE, textAlign: 'center'}}>
+                                                                                        Rate: {FormatUtils.styleRateUnitValue()(m.rate || 0)}
+                                                                                    </DIV>
+                                                                                </>
+                                                                            )}
+                                                                        </StyledButton>
+                                                                    </DIV>
                                                                 ))}
                                                             </DIV>
                                                         ))}
