@@ -82,6 +82,65 @@ export default class FileServerUtils {
 		return files;
 	}
 
+	public static async saveFile(filePath: string, content: string): Promise<boolean> {
+		const splitPath = filePath.split("/");
+		let path = "";
+		for (let i = 0; i < splitPath.length-1; i++) {
+			path += splitPath[i]
+			if (i != splitPath.length-2) {
+				path += "/"
+			}
+		}
+		
+		var builtPath = '';
+		for (let dir of path.split('/')) {
+			builtPath += '/' + dir
+			const settings = ServerConnection.makeSettings();
+			const url = settings.baseUrl + "api/contents" + builtPath;
+			const body = (await ServerConnection.makeRequest(
+				url, 
+				{
+					body: JSON.stringify({
+						'path': builtPath.substring(1),
+						'type': 'directory',
+					}),
+					method: 'PUT'
+				}, 
+				settings
+			).then(response => {
+				if (response.status !== 200 && response.status !== 201) {
+					throw new ServerConnection.ResponseError(response);
+				}
+				return response.json();
+			}));
+
+			if (!body) return false;
+		}
+
+		const settings = ServerConnection.makeSettings();
+		const url = settings.baseUrl + "api/contents/" + filePath;
+		const response = ServerConnection.makeRequest(
+			url, 
+			{
+				body: JSON.stringify({
+					content: content,
+					'format': 'text',
+					'type': 'file',
+				}),
+				method: 'PUT'
+			}, 
+			settings
+		).then(response => {
+			if (response.status !== 200 && response.status !== 201) {
+				throw new ServerConnection.ResponseError(response);
+			}
+			return response.json();
+		});
+		const body = (await response);
+		if (body) return true;
+		return false;
+	}
+
 	public static async saveNotebook(filePath: string, notebook: any): Promise<boolean> {
 		const splitPath = filePath.split("/");
 		let path = "";
@@ -145,8 +204,8 @@ export default class FileServerUtils {
 		if (n1.path > n2.path) return 1;
 		if (n1.path < n2.path) return -1;
 		if (n1.last_modified && n2.last_modified) {
-			if (n1.last_modified > n2.last_modified) return 1;
-			if (n1.last_modified < n2.last_modified) return -1;
+			if (new Date(n1.last_modified).getTime() < new Date(n2.last_modified).getTime()) return 1;
+			if (new Date(n1.last_modified).getTime() > new Date(n2.last_modified).getTime()) return -1;
 		}
 		return 0;
 	}
