@@ -6,12 +6,33 @@
 **/
 
 export default class FormatUtils {
-    public static formatCredit = (balance: number) => {
-        if (balance > 0) return '$0.00'
-        return '$' + (-balance).toFixed(2)
+    public static floorAndToFixed = (val: number, n = 0): string => {
+        if (val == null) return null
+        if (val == undefined) return undefined
+        const scale = Math.pow(10, n);
+        // To avoid errors with numbers with a lot of decimal points, round to n + 1 decimal places before flooring
+        return (Math.floor(+val.toFixed(n + 1) * scale) / scale).toFixed(n);
     }
     
-    public static msToTime(s: number) {
+    public static styleStorageOrEgress = (total: number, limit: number): string => {
+        var ret = FormatUtils.styleShortCapacityValue()(total, FormatUtils.styleCapacityUnit()(limit));
+        if (ret == '0' && total > 0) ret = '< 0.01'
+        return ret + ' of ' + FormatUtils.styleCapacityUnitValue()(limit)
+    }
+    
+    public static formatCost = (cost: number): string => {
+        if (cost > 0 && cost < 0.01) return '< $0.01'
+        var ret = '$' + FormatUtils.floorAndToFixed(cost, 2)
+        if (ret == '$0.00') return '--'
+        return ret
+    }
+
+    public static formatCredit = (balance: number) => {
+        if (balance > 0) return '$0.00'
+        return FormatUtils.formatCost(-balance)
+    }
+    
+    public static msToTime(s: number, includeMilliseconds: boolean = false) {
         var ms = s % 1000;
         s = (s - ms) / 1000;
         var secs = s % 60;
@@ -19,7 +40,7 @@ export default class FormatUtils {
         var mins = s % 60;
         var hrs = (s - mins) / 60;
     
-        return (hrs == 0 ? '' : (hrs < 10 ? '0' + hrs : hrs) + ':') + (mins < 10 ? '0' + mins : mins) + ':' + (secs < 10 ? '0' + secs : secs)/* + '.' + ms*/;
+        return (hrs == 0 ? '' : (hrs < 10 ? '0' + hrs : hrs) + ':') + (mins < 10 ? '0' + mins : mins) + ':' + (secs < 10 ? '0' + secs : secs) + (includeMilliseconds ? '.' + ms : '');
     }
 
     public static styleCapacityUnit() {
@@ -138,7 +159,9 @@ export default class FormatUtils {
     public static styleCapacityUnitValue() {
         return (value: number): string => {
             if (value == -1) return 'unsp'
-            if (value < Math.pow(1024, 2)) {
+            if (value < 1024) {
+                return value + ' bytes';
+            } else if (value < Math.pow(1024, 2)) {
                 return FormatUtils.customPrecision(value / Math.pow(1024, 1)) + ' KB';
             } else if (value < Math.pow(1024, 3)) {
                 return FormatUtils.customPrecision(value / Math.pow(1024, 2)) + ' MB';
